@@ -41,7 +41,7 @@ typedef enum {
 
 // text highlight entry
 
-class hlight { public:
+struct hlight {
     hl_kind kind;
     int color;
     string text;
@@ -68,7 +68,7 @@ struct editfile {
     bool modified, markmode, markreverse, showmarked;
 };
 
-class colorscheme { public:
+struct colorscheme {
     vector<hlight> hl;
     vector<int> difcolors;
 
@@ -78,7 +78,7 @@ class colorscheme { public:
     bool bold;
 };
 
-class undorecord { public:
+struct undorecord {
     tundoaction action;
     bool prevconnected;
     int x, y;
@@ -116,15 +116,15 @@ class texteditor: public abstractuicontrol {
 
 	void scancomments(bool visible);
 
-	void modification(tundoaction action, string data,
+	void modification(tundoaction action, const string data,
 	    bool connected = false, int curx = -1, int cury = -1);
 
 	bool endofline();
 	const char currentchar();
 
 	int count_clrcodes(char *cp, int pos);
-	void hl_comment(char *cp, char *txt, int color);
-	void hl_comment(char *cp, int st, int pend, int color);
+	int hl_comment(char *cp, char *txt, int color);
+	int hl_comment(char *cp, int st, int pend, int color);
 	void showline(int ln, int startx, int distance, int extrax = 0);
 
 	void marktext();
@@ -140,15 +140,15 @@ class texteditor: public abstractuicontrol {
 	void shiftmarkedblock(int delta);
 	
     public:
-	bool active, wrap, insertmode, modified;
+	bool active, wrap, insertmode, modified, smarttab;
 
-	int (*otherkeys)(texteditor *caller, int k);
-	void (*idle)(texteditor *caller);
+	int (*otherkeys)(texteditor &caller, int k);
+	void (*idle)(texteditor &caller);
 
 	texteditor();
 	~texteditor();
 
-	int load(string buf, const string id);
+	int load(const string buf, const string id);
 	int load(FILE *f, const string id);
 	int load(ifstream &f, const string id);
 	    // loads a file from char* or FILE opening
@@ -191,8 +191,10 @@ class texteditor: public abstractuicontrol {
 	void clearmark();
 	void copymark(FILE *f);
 	void copymark(char *p, int maxlen);
+
 	void insert(FILE *f);
-	void insert(char *p);
+	void insert(const string buf);
+
 	void delmark();
 	void undo();
 	
