@@ -1,7 +1,7 @@
 /*
 *
 * kkconsui dialogbox class
-* $Id: dialogbox.cc,v 1.3 2001/08/09 08:32:59 konst Exp $
+* $Id: dialogbox.cc,v 1.10 2001/11/20 14:09:57 konst Exp $
 *
 * Copyright (C) 1999-2001 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -110,6 +110,7 @@ textbrowser *dialogbox::getbrowser() {
 
 bool dialogbox::open(int &menuitem, int &baritem, void **ref = 0) {
     bool ret = false;
+    list<keybarassociation>::iterator i;
 
     it = this;
     if(first) redraw();
@@ -148,14 +149,23 @@ bool dialogbox::open(int &menuitem, int &baritem, void **ref = 0) {
 		    fin = true; ret = false;
 		    break;
 		default:
-		    if(otherkeys)
-		    if((k = otherkeys(this, k)) != -1) {
+		    i = find(it->kba.begin(), it->kba.end(), k);
+
+		    if(i != it->kba.end()) {
+		      if(it->bar) {
+			it->bar->item = i->baritem;
+			it->bar->redraw();
+			fin = ret = true;
+		      }
+		    }
+		    else if(otherkeys)
+		      if((k = otherkeys(*this, k)) != -1) {
 			menuitem = k;
 			fin = true;
-		    }
+		      }
 		    break;
 	    } else {
-		if(idle) idle(this);
+		if(idle) idle(*this);
 	    }
 	}
     }
@@ -181,11 +191,7 @@ bool dialogbox::open() {
 
 void dialogbox::redraw() {
     if(window) {
-	if(first) {
-	    window->open();
-	} else {
-	    window->redraw();
-	}
+	if(window->isopen()) window->redraw(); else window->open();
 
 	if(bar) {
 	    if(window->isbordered()) {
@@ -229,9 +235,24 @@ void dialogbox::addkey(int key, int baritem) {
     kba.push_back(keybarassociation(key, baritem));
 }
 
-void dialogbox::menuidle(verticalmenu *caller) {
+void dialogbox::addautokeys() {
+    int key;
+    vector<string>::const_iterator i;
+    string::const_iterator c;
+
+    if(bar) {
+	for(i = bar->items.begin(); i != bar->items.end(); i++) {
+	    for(c = i->begin(); (c != i->end()) && !isupper(*c); c++);
+	    key = c == i->end() ? key = *i->begin() : *c;
+	    addkey(tolower(key), i-bar->items.begin());
+	    addkey(toupper(key), i-bar->items.begin());
+	}
+    }
+}
+
+void dialogbox::menuidle(verticalmenu &caller) {
     if(it->idle) {
-	it->idle(it);
+	it->idle(*it);
     } else {
 	fd_set fds;
 	FD_ZERO(&fds);
@@ -240,9 +261,9 @@ void dialogbox::menuidle(verticalmenu *caller) {
     }
 }
 
-void dialogbox::browseridle(textbrowser *caller) {
+void dialogbox::browseridle(textbrowser &caller) {
     if(it->idle) {
-	it->idle(it);
+	it->idle(*it);
     } else {
 	fd_set fds;
 	FD_ZERO(&fds);
@@ -251,7 +272,7 @@ void dialogbox::browseridle(textbrowser *caller) {
     }
 }
 
-int dialogbox::menukeys(verticalmenu *caller, int k) {
+int dialogbox::menukeys(verticalmenu &caller, int k) {
     list<keybarassociation>::iterator i;
     bool found;
     int ip;
@@ -297,7 +318,7 @@ int dialogbox::menukeys(verticalmenu *caller, int k) {
 	    } else {
 		if(it->otherkeys) {
 		    sit = it;
-		    ip = it->otherkeys(it, k);
+		    ip = it->otherkeys(*it, k);
 		    it = sit;
 		    return ip;
 		}
@@ -308,7 +329,7 @@ int dialogbox::menukeys(verticalmenu *caller, int k) {
     return -1;
 }
 
-int dialogbox::browserkeys(textbrowser *caller, int k) {
+int dialogbox::browserkeys(textbrowser &caller, int k) {
     list<keybarassociation>::iterator i;
     bool found;
     int ip;
@@ -338,7 +359,7 @@ int dialogbox::browserkeys(textbrowser *caller, int k) {
 	    } else {
 		if(it->otherkeys) {
 		    sit = it;
-		    ip = it->otherkeys(it, k);
+		    ip = it->otherkeys(*it, k);
 		    it = sit;
 		    return ip;
 		}
@@ -356,6 +377,10 @@ dialogbox::keybarassociation::keybarassociation(int nkey, int nbarit) {
     baritem = nbarit;
 }
 
+bool dialogbox::keybarassociation::operator == (const int akey) {
+    return key == akey;
+}
+
 bool dialogbox::keybarassociation::operator != (const int akey) {
-    return key != akey;
+    return !(*this == akey);
 }
