@@ -1,7 +1,7 @@
 /*
 *
 * kkstrtext string related and text processing routines
-* $Id: kkstrtext.cc,v 1.3 2001/08/03 09:21:14 konst Exp $
+* $Id: kkstrtext.cc,v 1.10 2001/11/13 17:13:31 konst Exp $
 *
 * Copyright (C) 1999-2001 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -250,6 +250,23 @@ time_t str2time(char *sdate, char *mask, time_t *t) {
     return *t;
 }
 
+const string unmime(const string text) {
+    string r;
+    char *buf = new char[text.size()+1];
+    strcpy(buf, text.c_str());
+    r = unmime(buf);
+    delete buf;
+    return r;
+}
+
+const string mime(const string text) {
+    string r;
+    char *buf = new char[text.size()*3+1];
+    r = mime(buf, text.c_str());
+    delete buf;
+    return r;
+}
+
 char *unmime(char *text) {
     register int s, d;
     int htm;
@@ -298,6 +315,76 @@ char *strccat(char *dest, char c) {
     return dest;
 }
 
+vector<int> getquotelayout(const string haystack, const string qs, const string aescs) {
+    vector<int> r;
+    string needle, escs;
+    int pos, prevpos, curpos;
+    char cchar, qchar, prevchar;
+
+    qchar = 0;
+    curpos = prevpos = 0;
+    escs = (qs == aescs) ? "" : aescs;
+    needle = qs + escs;
+
+    while((pos = haystack.substr(curpos).find_first_of(needle)) != -1) {
+	curpos += pos;
+	cchar = *(haystack.begin()+curpos);
+
+	if(escs.find(cchar) != -1) {
+	    if(qchar)
+	    if(prevpos == curpos-1)
+	    if(escs.find(prevchar) != -1) {
+		/* Neutralize previous esc char */
+		cchar = 0;
+	    }
+	} else if(qs.find(cchar) != -1) {
+	    if(!((escs.find(prevchar) != -1) && (prevpos == curpos-1))) {
+		/* Wasn't an escape (right before this quote char) */
+
+		if(!qchar || (qchar == cchar)) {
+		    qchar = qchar ? 0 : cchar;
+		    r.push_back(curpos);
+		}
+	    }
+	}
+
+	prevpos = curpos++;
+	prevchar = cchar;
+    }
+
+    return r;
+}
+
+vector<int> getsymbolpositions(const string haystack, const string needles, const string qoutes, const string esc) {
+    vector<int> r, qp, nr;
+    vector<int>::iterator iq, ir;
+    int pos, st, ed, cpos;
+
+    for(cpos = 0; (pos = haystack.substr(cpos).find_first_of(needles)) != -1; ) {
+	r.push_back(cpos+pos);
+	cpos += pos+1;
+    }
+
+    qp = getquotelayout(haystack, qoutes, esc);
+    for(iq = qp.begin(); iq != qp.end(); iq++) {
+	if(!((iq-qp.begin()) % 2)) {
+	    st = *iq;
+	    ed = iq+1 != qp.end() ? *(iq+1) : haystack.size();
+	    nr.clear();
+
+	    for(ir = r.begin(); ir != r.end(); ir++) {
+		if(!(*ir > st && *ir < ed)) {
+		    nr.push_back(*ir);
+		}
+	    }
+
+	    r = nr;
+	}
+    }
+
+    return r;
+}
+
 #define CHECKESC(curpos, startpos, esc) \
     if(curpos > startpos+1) \
     if(strchr(esc, *(curpos-1))) \
@@ -320,8 +407,9 @@ const char *accept, const char *q, const char *esc = "") {
 
     while(p = strpbrk(p, cset)) {
 	if(strchr(q, *p)) {
-	    CHECKESC(p, s, esc);
-	    
+	    if(strcmp(esc, q))
+		CHECKESC(p, s, esc);
+
 	    if(!qchar) {
 		qchar = *p;
 	    } else {
@@ -345,7 +433,8 @@ const char *q, const char *esc = "") {
 
     for(i = 0; i < strlen(s); i++) {
 	if(strchr(q, s[i])) {
-	    CHECKESC(s+i, s, esc);
+	    if(strcmp(esc, q))
+		CHECKESC(s+i, s, esc);
 	    quote = !quote;
 	}
 
@@ -368,7 +457,8 @@ const char *q, const char *esc = "") {
 
 	while(r = strpbrk(r, q)) {
 	    if(r > p) break;
-	    CHECKESC(r, s, esc);
+	    if(strcmp(esc, q))
+		CHECKESC(r, s, esc);
 	    quote = !quote;
 	    r++;
 	}
@@ -859,3 +949,44 @@ int hex2int(const string ahex) {
 
     return r;
 }
+
+bool getconf(string &st, string &buf, ifstream &f) {
+    bool ret = false;
+    static string sect;
+
+    while(!f.eof() && !ret) {
+	getstring(f, buf);
+
+	if(buf.size())
+	switch(buf[0]) {
+	    case '%':
+		sect = buf.substr(1);
+		break;
+	    case '#':
+		break;
+	    default:
+		ret = buf.size();
+		break;
+	}
+    }
+
+    st = sect;
+    return ret;
+}
+
+bool getstring(istream &f, string &sbuf) {
+    static char buf[2048];
+    bool r;
+
+    if(r = !f.eof()) {
+	sbuf = "";
+
+	do {
+	    f.clear();
+	    f.getline(buf, 2048);
+	    sbuf += buf;
+	} while(!f.good() && !f.eof());
+    }
+
+    return r;
+}
