@@ -3,6 +3,7 @@
 
 #include <string>
 #include <vector>
+#include <fstream>
 
 #include <sys/time.h>
 #include <time.h>
@@ -10,6 +11,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdarg.h>
+#include <ctype.h>
 
 #include "conf.h"
 
@@ -65,6 +67,32 @@ bool iswholeword(const string s, int so, int eo);
 
 int hex2int(const string ahex);
 
+vector<int> getquotelayout(const string haystack, const string qs,
+    const string aescs);
+
+vector<int> getsymbolpositions(const string haystack,
+    const string needles, const string qoutes, const string esc);
+
+#define VGETSTRING(c, fmt) \
+    { \
+	va_list vgs__ap; char vgs__buf[1024]; \
+	va_start(vgs__ap, fmt); \
+	vsprintf(vgs__buf, fmt, vgs__ap); c = vgs__buf; \
+	va_end(vgs__ap); \
+    }
+
+const string justfname(const string fname);
+const string justpathname(const string fname);
+const string textscreen(const string text);
+const string i2str(int i);
+const string ui2str(int i);
+
+bool getconf(string &st, string &buf, ifstream &f);
+bool getstring(istream &f, string &buf);
+
+const string unmime(const string text);
+const string mime(const string text);
+
 __KTOOL_BEGIN_C
 
 int kwordcount(const char *strin, const char *delim);
@@ -117,13 +145,6 @@ char *mime(char *dst, const char *src);
 
 int parseformat(char *command, char *quotes, char *fmt, ...);
 
-const string justfname(const string fname);
-const string justpathname(const string fname);
-
-const string textscreen(const string text);
-const string i2str(int i);
-const string ui2str(int i);
-
 __KTOOL_END_C
 
 #endif
