@@ -1,7 +1,7 @@
 /*
 *
 * centericq core routines
-* $Id: centericq.cc,v 1.61 2001/12/14 16:19:10 konst Exp $
+* $Id: centericq.cc,v 1.66 2002/01/22 11:59:15 konst Exp $
 *
 * Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -218,7 +218,9 @@ void centericq::mainloop() {
 	    case ACT_EDITUSER:
 		c->save();
 		if(face.updatedetails(c)) {
-		    c->setdispnick(c->getnick());
+		    if(c->getdesc().pname == infocard)
+			c->setdispnick(c->getnick());
+
 		    c->save();
 		    face.relaxedupdate();
 		} else {
@@ -265,6 +267,7 @@ void centericq::mainloop() {
 		break;
 
 	    case ACT_MSG:
+	    case 0:
 		if(c->getmsgcount()) {
 		    readevents(c->getdesc());
 		} else {
@@ -298,12 +301,13 @@ void centericq::find() {
 	if(ret = face.finddialog(s)) {
 	    switch(s.pname) {
 		case icq:
-//                    ihook.sendsearchreq(s);
-//                    ret = face.findresults();
 		    if(s.uin) {
 			addcontact(imcontact(s.uin, s.pname));
 			ret = false;
+		    } else {
+			ret = face.findresults(s);
 		    }
+
 		    break;
 
 		case msn:
@@ -358,17 +362,17 @@ void centericq::userinfo(const imcontact cinfo) {
 bool centericq::updateconf() {
     bool r;
 
-    regsound snd = rsdontchange;
-    regcolor clr = rcdontchange;
+    icqconf::regsound snd = icqconf::rsdontchange;
+    icqconf::regcolor clr = icqconf::rcdontchange;
 
     if(r = face.updateconf(snd, clr)) {
-	if(snd != rsdontchange) {
+	if(snd != icqconf::rsdontchange) {
 	    conf.setregsound(snd);
 	    unlink(conf.getconfigfname("sounds").c_str());
 	    conf.loadsounds();
 	}
 
-	if(clr != rcdontchange) {
+	if(clr != icqconf::rcdontchange) {
 	    conf.setregcolor(clr);
 	    unlink(conf.getconfigfname("colorscheme").c_str());
 	    conf.loadcolors();
@@ -743,7 +747,7 @@ icqcontact *centericq::addcontact(const imcontact ic) {
 	}
     }
 
-    if(conf.getusegroups()) {
+    if(conf.getgroupmode() != icqconf::nogroups) {
 	groupid = face.selectgroup(_("Select a group to add the user to"));
 	if(!groupid) return 0;
     }
@@ -830,10 +834,17 @@ void centericq::setauto(imstatus astatus) {
     protocolname pname;
     imstatus stcurrent;
     static bool autoset = false;
+    bool nautoset;
 
     if((astatus == available) && !autoset)
 	return;
 
+    nautoset = autoset;
+
+    if(autoset && (astatus == available)) {
+	face.log(_("+ the user is back"));
+    }
+
     for(pname = icq; pname != protocolname_size; (int) pname += 1) {
 	abstracthook &hook = gethook(pname);
 	stcurrent = hook.getstatus();
@@ -846,16 +857,19 @@ void centericq::setauto(imstatus astatus) {
 
 	    default:
 		if(autoset && (astatus == available)) {
-		    face.log(_("+ the user is back"));
+		    face.log(_("+ [%s] status restored"),
+			conf.getprotocolname(pname).c_str());
+
 		    hook.restorestatus();
-		    autoset = false;
+		    nautoset = false;
 		} else {
 		    if(astatus == away && stcurrent == notavail)
 			break;
 
-		    if(!autoset && (astatus != stcurrent)) {
+		    if(astatus != stcurrent)
+		    if(!autoset || (autoset && (stcurrent == away))) {
 			hook.setautostatus(astatus);
-			autoset = true;
+			nautoset = true;
 
 			face.log(_("+ [%s] automatically set %s"),
 			    conf.getprotocolname(pname).c_str(),
@@ -865,6 +879,8 @@ void centericq::setauto(imstatus astatus) {
 		break;
 	}
     }
+
+    autoset = nautoset;
 }
 
 #define MINCK0(x, y)       (x ? (y ? (x > y ? y : x) : x) : y)
