@@ -1,7 +1,7 @@
 /*
 *
 * centericq main() function
-* $Id: centermain.cc,v 1.6 2001/08/17 19:11:58 konst Exp $
+* $Id: centermain.cc,v 1.14 2001/12/13 11:28:34 konst Exp $
 *
 * Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -23,27 +23,24 @@
 */
 
 #include "centericq.h"
-#include "icqhook.h"
 #include "icqface.h"
 #include "icqconf.h"
-#include "icqhist.h"
-#include "icqoffline.h"
 #include "icqcontacts.h"
 #include "icqmlist.h"
+#include "icqgroups.h"
 
 centericq cicq;
 icqconf conf;
 icqcontacts clist;
-icqhook ihook;
 icqface face;
-icqhistory hist;
-icqoffline offl;
 icqlist lst;
-
-struct icq_link icql;
+icqgroups groups;
 
 #ifdef ENABLE_NLS
-#include <locale.h>
+
+//#include <locale.h>
+#include <libintl.h>
+
 #endif
 
 int main(int argc, char **argv) {
@@ -53,13 +50,12 @@ int main(int argc, char **argv) {
 
     try {
 
-#if defined(HAVE_SETLOCALE) && defined(ENABLE_NLS)
-	setlocale(LC_ALL, "");
-	bindtextdomain("centericq", LOCALE_DIR);
-	textdomain("centericq");
+#ifdef ENABLE_NLS
+	bindtextdomain(PACKAGE, LOCALE_DIR);
+	textdomain(PACKAGE);
 #endif
 
-	cicq.commandline(argc, argv);
+	conf.commandline(argc, argv);
 	cicq.exec();
 
     } catch(int errcode) {
