@@ -4,6 +4,7 @@
 #include "icqface.h"
 #include "icqcontacts.h"
 #include "abstracthook.h"
+#include "imlogger.h"
 
 imeventmanager em;
 
@@ -50,6 +51,8 @@ void imeventmanager::store(const imevent &ev) {
 	    eventwrite(ev, offline);
 	}
     }
+
+    logger.putevent(ev);
 }
 
 // if incoming, store to the history immediately
@@ -69,10 +72,10 @@ vector<imevent *> imeventmanager::getevents(const imcontact &cont, time_t lastre
 	if(fhist.is_open()) {
 	    while(!fhist.eof()) {
 		rev = eventread(fhist);
-		rev->setcontact(cont);
 
 		if(rev) {
 		    if(rev->gettimestamp() > lastread) {
+			rev->setcontact(cont);
 			r.push_back(rev);
 		    } else {
 			delete rev;
@@ -120,6 +123,9 @@ void imeventmanager::eventwrite(const imevent &ev, eventwritemode mode) {
 	    } else if(ev.gettype() == imevent::authorization) {
 		const imauthorization *m = static_cast<const imauthorization *>(&ev);
 		m->write(fhist);
+	    } else if(ev.gettype() == imevent::email) {
+		const imemail *m = static_cast<const imemail *>(&ev);
+		m->write(fhist);
 	    }
 
 	    fhist.close();
