@@ -3,6 +3,7 @@
 
 #include "imcontact.h"
 #include "imevents.h"
+#include "imcontroller.h"
 
 enum hookcapabilities {
     hoptCanNotify = 2,
@@ -15,6 +16,7 @@ class abstracthook {
     protected:
 	imstatus manualstatus;
 	int fcapabilities;
+	verticalmenu *searchdest;
 
     public:
 	abstracthook();
@@ -48,6 +50,9 @@ class abstracthook {
 	virtual bool isdirectopen(const imcontact c) const;
 	virtual void requestinfo(const imcontact c);
 
+	virtual void lookup(const imsearchparams &params, verticalmenu &dest);
+	virtual void stoplookup();
+
 	int getcapabilities() const;
 };
 
