@@ -1,7 +1,7 @@
 /*
 *
 * centericq icq protocol handling class
-* $Id: icqhook.cc,v 1.27 2001/12/14 16:19:11 konst Exp $
+* $Id: icqhook.cc,v 1.49 2002/01/30 17:25:41 konst Exp $
 *
 * Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -28,10 +28,12 @@
 #include "icqcontacts.h"
 #include "accountmanager.h"
 #include "centericq.h"
+#include "imlogger.h"
 
-#include "userinfoconstants.h"
+#include "libicq2000/userinfoconstants.h"
+#include "libicq2000/userinfohelpers.h"
 
-#define PERIOD_ICQPING  60
+#define PERIOD_ICQPOLL  5
 
 icqhook ihook;
 
@@ -60,7 +62,9 @@ icqhook::icqhook() {
     cli.contactlist.connect(slot(this, &icqhook::contactlist_cb));
     cli.newuin.connect(slot(this, &icqhook::newuin_cb));
     cli.rate.connect(slot(this, &icqhook::rate_cb));
-    cli.statuschanged.connect(slot(this, &icqhook::statuschanged_cb));
+    cli.want_auto_resp.connect(slot(this, &icqhook::want_auto_resp_cb));
+    cli.search_result.connect(slot(this, &icqhook::search_result_cb));
+    cli.self_event.connect(slot(this, &icqhook::self_event_cb));
 
 #ifdef DEBUG
     cli.logger.connect(slot(this, &icqhook::logger_cb));
@@ -77,7 +81,9 @@ icqhook::~icqhook() {
     cli.contactlist.clear();
     cli.newuin.clear();
     cli.rate.clear();
-    cli.statuschanged.clear();
+    cli.self_event.clear();
+    cli.search_result.clear();
+    cli.want_auto_resp.clear();
 }
 
 void icqhook::init() {
@@ -98,13 +104,17 @@ void icqhook::connect() {
 	}
     }
 
+    if(!acc.server.empty()) cli.setLoginServerHost(acc.server);
+    if(acc.port) cli.setLoginServerPort(acc.port);
+
     cli.setUIN(acc.uin);
     cli.setPassword(acc.password);
 
     face.log(_("+ [icq] connecting to the server"));
 
-    cli.setInvisible(manualstatus == invisible);
-    cli.setStatus(stat2int[manualstatus]);
+    sendinvisible();
+    cli.setStatus(stat2int[manualstatus], manualstatus == invisible);
+    logger.putourstatus(icq, offline, manualstatus);
 
     time(&timer_reconnect);
     fonline = true;
@@ -112,6 +122,7 @@ void icqhook::connect() {
 }
 
 void icqhook::disconnect() {
+    logger.putourstatus(icq, getstatus(), offline);
     cli.setStatus(STATUS_OFFLINE);
 }
 
@@ -131,13 +142,37 @@ void icqhook::resolve() {
     }
 }
 
+void icqhook::sendinvisible() {
+    icqlist::iterator i;
+    Contact *c;
+    int k;
+/*
+    for(k = 0; k < clist.count; k++) {
+	if(c = cli.getContact(((icqcontact *) clist.at(k))->getdesc().uin)) {
+	    c->setInvisible(false);
+	}
+    }
+
+    for(i = lst.begin(); i != lst.end(); i++) {
+	switch(i->getstatus()) {
+	    case csinvisible:
+		if(c = cli.getContact(i->getdesc().uin)) {
+		    c->setInvisible(true);
+		}
+		break;
+	}
+    }
+*/
+}
+
 void icqhook::exectimers() {
     time_t tcurrent = time(0);
 
     if(logged()) {
-	if(tcurrent-timer_ping > PERIOD_ICQPING) {
-	    cli.PingServer();
-	    time(&timer_ping);
+	if(tcurrent-timer_poll > PERIOD_ICQPOLL) {
+	    cli.Poll();
+	    sendinvisible();
+	    time(&timer_poll);
 	} else if(tcurrent-timer_resolve > PERIOD_RESOLVE) {
 	    resolve();
 	    time(&timer_resolve);
@@ -262,31 +297,35 @@ bool icqhook::enabled() const {
 
 bool icqhook::send(const imevent &ev) {
     unsigned int uin = ev.getcontact().uin;
-    Contact ic(uin);
+    Contact *ic = cli.getContact(uin);
+
+    if(!ic) {
+	return false;
+    }
 
     if(ev.gettype() == imevent::message) {
 	const immessage *m = static_cast<const immessage *> (&ev);
-	cli.SendEvent(new NormalMessageEvent(&ic, rusconv("kw", m->gettext())));
+	cli.SendEvent(new NormalMessageEvent(ic, rusconv("kw", m->gettext())));
 
     } else if(ev.gettype() == imevent::url) {
 	const imurl *m = static_cast<const imurl *> (&ev);
-	cli.SendEvent(new URLMessageEvent(&ic,
+	cli.SendEvent(new URLMessageEvent(ic,
 	    rusconv("kw", m->getdescription()),
 	    rusconv("kw", m->geturl())));
 
     } else if(ev.gettype() == imevent::sms) {
 	const imsms *m = static_cast<const imsms *> (&ev);
-	ic.setMobileNo(clist.get(ev.getcontact())->getbasicinfo().cellular);
-	cli.SendEvent(new SMSMessageEvent(&ic, rusconv("kw", m->gettext()), false));
+	ic->setMobileNo(clist.get(ev.getcontact())->getbasicinfo().cellular);
+	cli.SendEvent(new SMSMessageEvent(ic, rusconv("kw", m->gettext()), false));
 
     } else if(ev.gettype() == imevent::authorization) {
 	const imauthorization *m = static_cast<const imauthorization *> (&ev);
-	cli.SendEvent(new AuthAckEvent(&ic,
+	cli.SendEvent(new AuthAckEvent(ic,
 	    rusconv("kw", m->gettext()), m->getgranted()));
 
     } else if(ev.gettype() == imevent::sms) {
 	const imsms *m = static_cast<const imsms *> (&ev);
-	cli.SendEvent(new SMSMessageEvent(&ic, rusconv("kw", m->gettext()),
+	cli.SendEvent(new SMSMessageEvent(ic, rusconv("kw", m->gettext()),
 	    true));
 
     } else {
@@ -300,7 +339,7 @@ void icqhook::sendnewuser(const imcontact c) {
     if(logged()) {
 	Contact ic(c.uin);
 	cli.addContact(ic);
-	cli.fetchSimpleContactInfo(&ic);
+	cli.fetchDetailContactInfo(cli.getContact(c.uin));
     }
 }
 
@@ -309,8 +348,9 @@ void icqhook::setautostatus(imstatus st) {
 	if(getstatus() == offline) {
 	    connect();
 	} else {
-	    cli.setInvisible(st == invisible);
-	    cli.setStatus(stat2int[st]);
+	    sendinvisible();
+	    logger.putourstatus(icq, getstatus(), st);
+	    cli.setStatus(stat2int[st], st == invisible);
 	}
     } else {
 	if(getstatus() != offline) {
@@ -330,6 +370,13 @@ imstatus icqhook::getstatus() const {
 }
 
 bool icqhook::regconnect(const string aserv) {
+    int pos;
+
+    if((pos = aserv.find(":")) != -1) {
+	cli.setLoginServerHost(aserv.substr(0, pos));
+	cli.setLoginServerPort(strtoul(aserv.substr(pos+1).c_str(), 0, 0));
+    }
+
     return true;
 }
 
@@ -355,6 +402,8 @@ bool icqhook::regattempt(unsigned int &auin, const string apassword) {
 	tv.tv_sec = 30;
 	tv.tv_usec = 0;
 
+	select(hsockfd+1, &rfds, &wfds, &efds, &tv);
+
 	if(isoursocket(rfds, wfds, efds)) {
 	    main();
 	}
@@ -386,22 +435,115 @@ imstatus icqhook::icq2imstatus(const Status st) const {
 
 void icqhook::requestinfo(const imcontact c) {
     if(logged()) {
-	Contact ic(c.uin);
-	cli.addContact(ic);
-	cli.fetchSimpleContactInfo(&ic);
+	if(c == imcontact(conf.getourid(icq).uin, icq)) {
+	    // Our info is requested
+	    cli.fetchSelfDetailContactInfo();
+	} else {
+	    Contact *icont = cli.getContact(c.uin);
+
+	    if(!icont) {
+		Contact ic(c.uin);
+		cli.addContact(ic);
+	    } else {
+		cli.fetchDetailContactInfo(icont);
+	    }
+	}
     }
 }
 
-const string icqhook::getcountryname(int code) const {
-    int i;
+void icqhook::lookup(const imsearchparams &params, verticalmenu &dest) {
+    ICQ2000::Sex sex;
 
-    for(i = 0; i < Country_table_size; i++) {
-	if(Country_table[i].code == code) {
-	    return Country_table[i].name;
-	}
+    searchdest = &dest;
+
+    sex = params.gender == genderMale ? ICQ2000::SEX_MALE :
+	params.gender == genderFemale ? ICQ2000::SEX_FEMALE :
+	ICQ2000::SEX_UNSPECIFIED;
+
+    if(!params.email.empty() || params.minage || params.maxage ||
+    !params.city.empty() || !params.state.empty() ||
+    !params.company.empty() || !params.department.empty() ||
+    !params.position.empty() || params.onlineonly ||
+    params.country || params.language || (sex != ICQ2000::SEX_UNSPECIFIED)) {
+	searchevent = cli.searchForContacts(params.nick, params.firstname,
+	    params.lastname, params.email, params.minage, params.maxage,
+	    sex, params.language, params.city, params.state, params.country,
+	    params.company, params.department, params.position,
+	    params.onlineonly);
+    } else {
+	searchevent = cli.searchForContacts(params.nick, params.firstname,
+	    params.lastname);
     }
+}
 
-    return "";
+void icqhook::sendupdateuserinfo(const icqcontact &c) {
+    Contact *ic = cli.getSelfContact();
+
+    MainHomeInfo &home = ic->getMainHomeInfo();
+    HomepageInfo &hpage = ic->getHomepageInfo();
+    WorkInfo &work = ic->getWorkInfo();
+
+    icqcontact::basicinfo cbinfo = c.getbasicinfo();
+    icqcontact::moreinfo cminfo = c.getmoreinfo();
+    icqcontact::workinfo cwinfo = c.getworkinfo();
+
+    /* basic information */
+
+    ic->setAlias(rusconv("kw", c.getnick()));
+    ic->setFirstName(rusconv("kw", cbinfo.fname));
+    ic->setLastName(rusconv("kw", cbinfo.lname));
+    ic->setEmail(rusconv("kw", cbinfo.email));
+    ic->setAuthReq(cbinfo.requiresauth);
+
+    ic->setAboutInfo(rusconv("kw", c.getabout()));
+
+    home.city = rusconv("kw", cbinfo.city);
+    home.state = rusconv("kw", cbinfo.state);
+    home.phone = rusconv("kw", cbinfo.phone);
+    home.fax = rusconv("kw", cbinfo.fax);
+    home.street = rusconv("kw", cbinfo.street);
+    home.setMobileNo(rusconv("kw", cbinfo.cellular));
+
+    home.zip = i2str(cbinfo.zip);
+    home.country = cbinfo.country;
+    home.timezone = UserInfoHelpers::getSystemTimezone();
+
+    /* more information */
+
+    hpage.age = cminfo.age;
+
+    hpage.sex =
+	cminfo.gender == genderFemale ? SEX_FEMALE :
+	cminfo.gender == genderMale ? SEX_MALE :
+	    SEX_UNSPECIFIED;
+
+    hpage.homepage = rusconv("kw", cminfo.homepage);
+    hpage.birth_day = cminfo.birth_day;
+    hpage.birth_month = cminfo.birth_month;
+    hpage.birth_year = cminfo.birth_year;
+
+    hpage.lang1 = cminfo.lang1;
+    hpage.lang2 = cminfo.lang2;
+    hpage.lang3 = cminfo.lang3;
+
+    /* work information */
+
+    work.city = rusconv("kw", cwinfo.city);
+    work.state = rusconv("kw", cwinfo.state);
+    work.street = rusconv("kw", cwinfo.street);
+    work.company_name = rusconv("kw", cwinfo.company);
+    work.company_dept = rusconv("kw", cwinfo.dept);
+    work.company_position = rusconv("kw", cwinfo.position);
+    work.company_web = rusconv("kw", cwinfo.homepage);
+
+    work.zip = i2str(cwinfo.zip);
+    work.country = cwinfo.country;
+
+    ic->setMainHomeInfo(home);
+    ic->setHomepageInfo(hpage);
+    ic->setWorkInfo(work);
+
+    cli.uploadSelfDetails();
 }
 
 // ----------------------------------------------------------------------------
@@ -409,11 +551,27 @@ const string icqhook::getcountryname(int code) const {
 void icqhook::connected_cb(ConnectedEvent *ev) {
     flogged = true;
 
-    time(&timer_ping);
+    time(&timer_poll);
     timer_resolve = time(0)-PERIOD_RESOLVE+2;
 
     face.log(_("+ [icq] logged in"));
     face.update();
+
+    string buf;
+    ifstream f(conf.getconfigfname("icq-infoset").c_str());
+
+    if(f.is_open()) {
+	getstring(f, buf); cli.getSelfContact()->setAlias(buf);
+	getstring(f, buf); cli.getSelfContact()->setEmail(buf);
+	getstring(f, buf); cli.getSelfContact()->setFirstName(buf);
+	getstring(f, buf); cli.getSelfContact()->setLastName(buf);
+	f.close();
+
+	cli.getSelfContact()->getMainHomeInfo().timezone = UserInfoHelpers::getSystemTimezone();
+	cli.uploadSelfDetails();
+
+	unlink(conf.getconfigfname("icq-infoset").c_str());
+    }
 }
 
 void icqhook::disconnected_cb(DisconnectedEvent *ev) {
@@ -476,10 +634,12 @@ bool icqhook::messaged_cb(MessageEvent *ev) {
 
 	    if(!c)
 	    if(c = clist.addnew(imcontact(0, infocard), true)) {
-		c->setdispnick("mobile");
 		icqcontact::basicinfo b = c->getbasicinfo();
 		b.cellular = r->getSender();
+
 		c->setbasicinfo(b);
+
+		c->setdispnick(b.cellular);
 		c->setnick(b.cellular);
 	    }
 
@@ -508,19 +668,75 @@ bool icqhook::messaged_cb(MessageEvent *ev) {
 	}
 
     } else if(ev->getType() == MessageEvent::AuthAck) {
+    } else if(ev->getType() == MessageEvent::EmailEx) {
+	EmailExEvent *r;
+
+	if(r = dynamic_cast<EmailExEvent *>(ev)) {
+	    icqcontact *c = clist.getemail(r->getEmail());
+
+	    if(!c)
+	    if(c = clist.addnew(imcontact(0, infocard), true)) {
+		c->setdispnick(r->getEmail());
+		c->setnick(r->getEmail());
+
+		icqcontact::basicinfo b = c->getbasicinfo();
+
+		if(r->getSender() != r->getEmail()) {
+		    int pos = r->getSender().find(" ");
+
+		    if(pos != -1) {
+			b.fname = r->getSender().substr(0, pos);
+			b.lname = r->getSender().substr(pos+1);
+		    } else {
+			b.fname = r->getSender();
+		    }
+		}
+
+		b.email = r->getEmail();
+		c->setbasicinfo(b);
+	    }
+
+	    if(c) {
+		em.store(imemail(c->getdesc(), imevent::incoming,
+		    rusconv("wk", r->getMessage())));
+	    }
+	}
+
+    } else if(ev->getType() == MessageEvent::AwayMessage) {
+	AwayMessageEvent *r;
+	if(r = dynamic_cast<AwayMessageEvent *>(ev)) {
+	    em.store(immessage(ic, imevent::incoming,
+		string() + _("* Away message:") + "\n\n" +
+		rusconv("wk", r->getMessage())));
+	}
+
+    } else if(ev->getType() == MessageEvent::UserAdd) {
+	UserAddEvent *r;
+	if(r = dynamic_cast<UserAddEvent *>(ev)) {
+	    em.store(immessage(ic, imevent::incoming,
+		string() + _("* The user has added you to his/her contact list")));
+	}
+
     }
 
     return true;
 }
 
 void icqhook::messageack_cb(MessageEvent *ev) {
-    Contact *ic;
+    imcontact ic;
+    icqcontact *c;
 
-    if(ev->isFinished() && ev->isDelivered()) {
-	if(ev->getType() != MessageEvent::AwayMessage) {
-	    if(ic = ev->getContact()) {
-//                busy.erase(ic->getUIN());
-	    }
+    ic = imcontact(ev->getContact()->getUIN(), icq);
+    c = clist.get(ic);
+
+    if(ev->isFinished()) {
+	switch(ev->getType()) {
+	    case MessageEvent::SMS:
+		if(!ev->isDelivered()) {
+		    face.log(_("+ [icq] failed SMS to %s, %s"),
+			c->getdispnick().c_str(), ic.totext().c_str());
+		}
+		break;
 	}
     }
 }
@@ -528,8 +744,8 @@ void icqhook::messageack_cb(MessageEvent *ev) {
 void icqhook::contactlist_cb(ContactListEvent *ev) {
     icqcontact *c = clist.get(imcontact(ev->getUIN(), icq));
     char buf[64];
+    string lastip, sbuf;
     int ip;
-    string lastip;
 
     switch(ev->getType()) {
 	case ContactListEvent::StatusChange:
@@ -537,15 +753,33 @@ void icqhook::contactlist_cb(ContactListEvent *ev) {
 	    if(c) {
 		Contact *ic = cli.getContact(ev->getUIN());
 		StatusChangeEvent *tev = dynamic_cast<StatusChangeEvent*>(ev);
+
+		logger.putonline(c->getdesc(),
+		    c->getstatus(),
+		    icq2imstatus(tev->getStatus()));
+
 		c->setstatus(icq2imstatus(tev->getStatus()));
 
 		if(c->getstatus() != offline) {
-		    if(inet_ntop(AF_INET, &(ip = ic->getExtIP()), buf, 64))
-			lastip = buf;
+		    c->setlastseen();
 
-		    if(inet_ntop(AF_INET, &(ip = ic->getLanIP()), buf, 64)) {
-			if(!lastip.empty()) lastip += " ";
-			lastip += buf;
+		    if(inet_ntop(AF_INET, &(ip = ntohl(ic->getExtIP())), buf, 64)) {
+			lastip = buf;
+		    }
+
+		    if(lastip.find_first_not_of(".0") != -1) {
+			if(inet_ntop(AF_INET, &(ip = ntohl(ic->getLanIP())), buf, 64)) {
+			    sbuf = buf;
+
+			    if(sbuf.find_first_not_of(".0") != -1) {
+				if(lastip != sbuf) {
+				    if(!lastip.empty()) lastip += " ";
+				    lastip += sbuf;
+				}
+			    }
+			}
+
+			c->setlastip(lastip);
 		    }
 		}
 	    }
@@ -557,10 +791,23 @@ void icqhook::contactlist_cb(ContactListEvent *ev) {
 
 		if(!c) {
 		    c = clist.get(contactroot);
+		    if(ev->getUIN() == conf.getourid(icq).uin) {
+			ic = cli.getSelfContact();
+		    }
 		}
 
-		icqcontact::basicinfo cbinfo = c->getbasicinfo();
 		MainHomeInfo &home = ic->getMainHomeInfo();
+		HomepageInfo &hpage = ic->getHomepageInfo();
+		WorkInfo &work = ic->getWorkInfo();
+		PersonalInterestInfo &pint = ic->getPersonalInterestInfo();
+		BackgroundInfo &backg = ic->getBackgroundInfo();
+		EmailInfo &email = ic->getEmailInfo();
+
+		icqcontact::basicinfo cbinfo = c->getbasicinfo();
+		icqcontact::moreinfo cminfo = c->getmoreinfo();
+		icqcontact::workinfo cwinfo = c->getworkinfo();
+
+		/* basic information */
 
 		cbinfo.fname = rusconv("wk", ic->getFirstName());
 		cbinfo.lname = rusconv("wk", ic->getLastName());
@@ -570,23 +817,90 @@ void icqhook::contactlist_cb(ContactListEvent *ev) {
 		cbinfo.phone = rusconv("wk", home.phone);
 		cbinfo.fax = rusconv("wk", home.fax);
 		cbinfo.street = rusconv("wk", home.street);
+		cbinfo.requiresauth = ic->getAuthReq();
 
-		if(!home.cellular.empty())
-		    cbinfo.cellular = rusconv("wk", home.cellular);
+		if(!home.getMobileNo().empty())
+		    cbinfo.cellular = rusconv("wk", home.getMobileNo());
 
 		cbinfo.zip = strtoul(home.zip.c_str(), 0, 0);
-		cbinfo.country = getcountryname(home.country);
+		cbinfo.country = home.country;
 
-		icqcontact::moreinfo cminfo = c->getmoreinfo();
-		HomepageInfo &hpage = ic->getHomepageInfo();
+		/* more information */
 
 		cminfo.age = hpage.age;
-		cminfo.gender = genderUnspec;
+
+		cminfo.gender =
+		    hpage.sex == 1 ? genderFemale :
+		    hpage.sex == 2 ? genderMale :
+			genderUnspec;
+
 		cminfo.homepage = rusconv("wk", hpage.homepage);
 		cminfo.birth_day = hpage.birth_day;
 		cminfo.birth_month = hpage.birth_month;
 		cminfo.birth_year = hpage.birth_year;
 
+		cminfo.lang1 = hpage.lang1;
+		cminfo.lang2 = hpage.lang2;
+		cminfo.lang3 = hpage.lang3;
+
+		cminfo.timezone = home.timezone;
+
+		/* work information */
+
+		cwinfo.city = rusconv("wk", work.city);
+		cwinfo.state = rusconv("wk", work.state);
+		cwinfo.street = rusconv("wk", work.street);
+		cwinfo.company = rusconv("wk", work.company_name);
+		cwinfo.dept = rusconv("wk", work.company_dept);
+		cwinfo.position = rusconv("wk", work.company_position);
+		cwinfo.homepage = rusconv("wk", work.company_web);
+
+		cwinfo.zip = strtoul(work.zip.c_str(), 0, 0);
+		cwinfo.country = work.country;
+
+		/* personal interests */
+
+		vector<string> pintinfo;
+		list<PersonalInterestInfo::Interest>::iterator ii;
+
+		for(ii = pint.interests.begin(); ii != pint.interests.end(); ii++) {
+		    int k = ii->first-Interests_offset;
+
+		    if(k >= 0 && k < Interests_table_size) {
+			sbuf = (string) Interests_table[k];
+		    } else {
+			sbuf = "";
+		    }
+
+		    if(!ii->second.empty()) {
+			if(!sbuf.empty()) sbuf += ": ";
+			sbuf += rusconv("wk", ii->second);
+		    }
+
+		    if(!sbuf.empty()) pintinfo.push_back(sbuf);
+		}
+
+		/* education background */
+
+		vector<string> backginfo;
+		list<BackgroundInfo::School>::iterator isc;
+
+		for(isc = backg.schools.begin(); isc != backg.schools.end(); isc++) {
+		    sbuf = "";
+
+		    for(int k = 0; k < Background_table_size; k++) {
+			if(Background_table[k].code == isc->first) {
+			    sbuf = (string) Background_table[k].name + ": ";
+			    break;
+			}
+		    }
+
+		    sbuf += rusconv("wk", isc->second);
+		    if(!sbuf.empty()) backginfo.push_back(sbuf);
+		}
+
+		/* nicknames stuff */
+
 		string nick = rusconv("wk", ic->getAlias());
 
 		if((c->getnick() == c->getdispnick())
@@ -597,6 +911,9 @@ void icqhook::contactlist_cb(ContactListEvent *ev) {
 		c->setnick(nick);
 		c->setbasicinfo(cbinfo);
 		c->setmoreinfo(cminfo);
+		c->setworkinfo(cwinfo);
+		c->setinterests(pintinfo);
+		c->setbackground(backginfo);
 		c->setabout(rusconv("wk", ic->getAboutInfo()));
 
 		face.relaxedupdate();
@@ -611,6 +928,9 @@ void icqhook::contactlist_cb(ContactListEvent *ev) {
 
 	case ContactListEvent::MessageQueueChanged:
 	    break;
+
+	case ContactListEvent::ServerBasedContact:
+	    break;
     }
 }
 
@@ -625,6 +945,9 @@ void icqhook::logger_cb(LogEvent *ev) {
     switch(ev->getType()) {
 	case LogEvent::PACKET:
 	case LogEvent::DIRECTPACKET:
+#if PACKETDEBUG
+	    face.log(ev->getMessage());
+#endif
 	    break;
 
 	default:
@@ -660,6 +983,52 @@ void icqhook::socket_cb(SocketEvent *ev) {
     }
 }
 
-void icqhook::statuschanged_cb(MyStatusChangeEvent *ev) {
-    face.update();
+void icqhook::want_auto_resp_cb(AwayMessageEvent *ev) {
+    ev->setMessage("");
+}
+
+void icqhook::search_result_cb(SearchResultEvent *ev) {
+    if(ev == searchevent) {
+	string line;
+	Contact *c = ev->getLastContactAdded();
+
+	if(searchdest && c) {
+	    line = (c->getStatus() == STATUS_ONLINE ? "o " : "  ") +
+		rusconv("wk", c->getAlias());
+
+	    if(line.size() > 12) line.resize(12);
+	    else line += string(12-line.size(), ' ');
+
+	    line += " " + 
+		rusconv("wk", c->getFirstName()) + " " +
+		rusconv("wk", c->getLastName());
+
+	    if(!c->getEmail().empty())
+		line += " <" + rusconv("wk", c->getEmail()) + ">";
+
+	    searchdest->additem(0, c->getUIN(), line);
+
+	    searchdest->redraw();
+	}
+
+	if(ev->isFinished()) {
+	    face.log(_("+ [icq] whitepages search finished, %d found"),
+		ev->getContactList().size());
+	}
+    }
+}
+
+void icqhook::self_event_cb(SelfEvent *ev) {
+    switch(ev->getType()) {
+	case SelfEvent::MyStatusChange:
+	    face.update();
+	    break;
+
+	case SelfEvent::MyUserInfoChange:
+	    {
+		UserInfoChangeEvent cl(cli.getSelfContact());
+		contactlist_cb(&cl);
+	    }
+	    break;
+    }
 }
