@@ -2,8 +2,9 @@
 #define __ICQHOOK_H__
 
 #include "abstracthook.h"
-#include "Client.h"
-#include "events.h"
+
+#include "libicq2000/Client.h"
+#include "libicq2000/events.h"
 
 using namespace ICQ2000;
 
@@ -13,9 +14,10 @@ class icqhook: public abstracthook, public SigC::Object {
 
 	vector<int> rfds, wfds, efds;
 
-	time_t timer_reconnect, timer_ping, timer_resolve;
+	time_t timer_reconnect, timer_poll, timer_resolve;
 	bool fonline, flogged;
 	unsigned int reguin;
+	SearchResultEvent *searchevent;
 
 	void connected_cb(ConnectedEvent *ev);
 	void disconnected_cb(DisconnectedEvent *ev);
@@ -26,12 +28,14 @@ class icqhook: public abstracthook, public SigC::Object {
 	void rate_cb(RateInfoChangeEvent *ev);
 	void logger_cb(LogEvent *ev);
 	void socket_cb(SocketEvent *ev);
-	void statuschanged_cb(MyStatusChangeEvent *ev);
+	void want_auto_resp_cb(AwayMessageEvent *ev);
+	void search_result_cb(SearchResultEvent *ev);
+	void self_event_cb(SelfEvent *ev);
 
 	imstatus icq2imstatus(const Status st) const;
-	const string getcountryname(int code) const;
 
 	void resolve();
+	void sendinvisible();
 
     public:
 	icqhook();
@@ -62,6 +66,9 @@ class icqhook: public abstracthook, public SigC::Object {
 
 	bool regconnect(const string aserv);
 	bool regattempt(unsigned int &auin, const string apassword);
+
+	void lookup(const imsearchparams &params, verticalmenu &dest);
+	void sendupdateuserinfo(const icqcontact &c);
 };
 
 extern icqhook ihook;
