@@ -16,8 +16,10 @@ class msnhook : public abstracthook {
 	static void disconnected(void *data);
 	static void log(void *data);
 	static void ring(void *data);
+	static void mailed(void *data);
 
-	imstatus msn2imstatus(int st) const;
+	static imstatus msn2imstatus(int st);
+	static bool isourid(const string nick);
 
     public:
 	msnhook();
