@@ -1,7 +1,7 @@
 /*
 *
 * centericq configuration handling routines
-* $Id: icqconf.cc,v 1.30 2001/12/11 12:46:06 konst Exp $
+* $Id: icqconf.cc,v 1.35 2002/01/28 14:09:34 konst Exp $
 *
 * Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -33,9 +33,11 @@
 icqconf::icqconf() {
     rs = rscard;
     rc = rcdark;
+    fgroupmode = nogroups;
+
     autoaway = autona = 0;
 
-    hideoffline = antispam = usegroups = russian = false;
+    hideoffline = antispam = russian = makelog = false;
     savepwd = mailcheck = true;
 
     basedir = (string) getenv("HOME") + "/.centericq/";
@@ -92,7 +94,9 @@ void icqconf::loadmainconfig() {
 	    if(param == "sockshost") setsockshost(buf); else
 	    if(param == "socksusername") socksuser = buf; else
 	    if(param == "sockspass") sockspass = buf; else
-	    if(param == "usegroups") usegroups = true; else {
+	    if((param == "usegroups") || (param == "group1")) fgroupmode = group1; else
+	    if(param == "group2") fgroupmode = group2; else
+	    if(param == "log") makelog = true; else {
 		for(pname = icq; pname != protocolname_size; (int) pname += 1) {
 		    buf = getprotocolname(pname);
 		    if(param.substr(0, buf.size()) == buf) {
@@ -160,7 +164,14 @@ void icqconf::save() {
 	if(getquote()) f << "quotemsgs" << endl;
 	if(getantispam()) f << "antispam" << endl;
 	if(getmailcheck()) f << "mailcheck" << endl;
-	if(getusegroups()) f << "usegroups" << endl;
+
+
+	switch(getgroupmode()) {
+	    case group1: f << "group1" << endl; break;
+	    case group2: f << "group2" << endl; break;
+	}
+
+	if(getmakelog()) f << "log" << endl;
 
 	for(ia = accounts.begin(); ia != accounts.end(); ia++) {
 	    ia->write(f);
@@ -173,7 +184,7 @@ void icqconf::save() {
 int icqconf::getcolor(int npair) const {
     return
 	find(boldcolors.begin(), boldcolors.end(), npair) != boldcolors.end()
-	? boldcolor(npair) : color(npair);
+	? boldcolor(npair) : normalcolor(npair);
 }
 
 void icqconf::loadcolors() {
@@ -344,13 +355,15 @@ void icqconf::loadsounds() {
 	    skey = getword(buf);
 
 	    it = imevent::imeventtype_size;
-	    isn = soundnames.begin();
 
-	    for(; (isn != soundnames.end()) && (it == imevent::imeventtype_size); isn++)
-		if(skey == isn->second)
+	    for(isn = soundnames.begin(); isn != soundnames.end(); isn++) {
+		if(skey == isn->second) {
 		    it = isn->first;
+		    break;
+		}
+	    }
 
-	    if(isn == soundnames.end())
+	    if(it == imevent::imeventtype_size)
 		continue;
 
 	    if(suin != "*") {
@@ -407,19 +420,19 @@ void icqconf::loadactions() {
     }
 }
 
-regcolor icqconf::getregcolor() const {
+icqconf::regcolor icqconf::getregcolor() const {
     return rc;
 }
 
-void icqconf::setregcolor(regcolor c) {
+void icqconf::setregcolor(icqconf::regcolor c) {
     rc = c;
 }
 
-regsound icqconf::getregsound() const {
+icqconf::regsound icqconf::getregsound() const {
     return rs;
 }
 
-void icqconf::setregsound(regsound s) {
+void icqconf::setregsound(icqconf::regsound s) {
     rs = s;
 }
 
@@ -644,6 +657,22 @@ void icqconf::commandline(int argc, char **argv) {
     }
 }
 
+bool icqconf::getmakelog() const {
+    return makelog;
+}
+
+void icqconf::setmakelog(bool slog) {
+    makelog = slog;
+}
+
+icqconf::groupmode icqconf::getgroupmode() const {
+    return fgroupmode;
+}
+
+void icqconf::setgroupmode(icqconf::groupmode amode) {
+    fgroupmode = amode;
+}
+
 // ----------------------------------------------------------------------------
 
 icqconf::imaccount::imaccount() {
@@ -676,22 +705,26 @@ void icqconf::imaccount::write(ofstream &f) {
 
 void icqconf::imaccount::read(const string spec) {
     int pos = spec.find("_");
-    string pname, buf;
+    string spname, buf;
 
     if(pos != -1) {
 	buf = spec;
-	pname = getword(buf.erase(0, pos+1));
+	spname = getword(buf.erase(0, pos+1));
 
-	if(pname == "nick") nickname = buf; else
-	if(pname == "uin") uin = strtoul(buf.c_str(), 0, 0); else
-	if(pname == "pass") password = buf; else
-	if(pname == "server") {
+	if(spname == "nick") nickname = buf; else
+	if(spname == "uin") uin = strtoul(buf.c_str(), 0, 0); else
+	if(spname == "pass") password = buf; else
+	if(spname == "server") {
 	    if((pos = buf.find(":")) != -1) {
 		server = buf.substr(0, pos);
 		port = strtoul(buf.substr(pos+1).c_str(), 0, 0);
 	    } else {
 		server = buf;
 	    }
+
+	    if(pname == icq)
+	    if(server == "icq.mirabilis.com")
+		server = "";
 	}
     }
 }
