@@ -1,7 +1,7 @@
 /*
 *
 * centericq single icq contact class
-* $Id: icqcontact.cc,v 1.35 2001/12/13 11:28:34 konst Exp $
+* $Id: icqcontact.cc,v 1.42 2002/01/26 14:01:37 konst Exp $
 *
 * Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -29,6 +29,9 @@
 #include "icqface.h"
 #include "abstracthook.h"
 
+#include <time.h>
+#include <libicq2000/userinfohelpers.h>
+
 icqcontact::icqcontact(const imcontact adesc) {
     string fname, tname;
     imevent::imeventtype ie;
@@ -161,24 +164,24 @@ void icqcontact::save() {
 		winfo.company << endl <<
 		winfo.dept << endl <<
 		winfo.position << endl <<
-		endl <<
+		(int) minfo.timezone << endl <<
 		winfo.homepage << endl <<
 		(int) minfo.age << endl <<
 		(int) minfo.gender << endl <<
 		minfo.homepage << endl <<
-		endl <<
-		endl <<
-		endl <<
+		minfo.lang1 << endl <<
+		minfo.lang2 << endl <<
+		minfo.lang3 << endl <<
 		minfo.birth_day << endl <<
 		minfo.birth_month << endl <<
 		minfo.birth_year << endl <<
-		endl <<
-		endl <<
-		endl <<
-		endl <<
-		endl <<
-		endl <<
-		endl <<
+		(interests.size() > 0 ? *(interests.begin()+0) : "") << endl <<
+		(interests.size() > 1 ? *(interests.begin()+1) : "") << endl <<
+		(interests.size() > 2 ? *(interests.begin()+2) : "") << endl <<
+		(interests.size() > 3 ? *(interests.begin()+3) : "") << endl <<
+		(background.size() > 0 ? *(background.begin()+0) : "") << endl <<
+		(background.size() > 1 ? *(background.begin()+1) : "") << endl <<
+		(background.size() > 2 ? *(background.begin()+2) : "") << endl <<
 		endl <<
 		endl <<
 		lastip << endl <<
@@ -238,35 +241,35 @@ void icqcontact::load() {
 		case 10: binfo.street = buf; break;
 		case 11: binfo.cellular = buf; break;
 		case 12: binfo.zip = strtoul(buf, 0, 0); break;
-		case 13: binfo.country = buf; break;
+		case 13: binfo.country = strtoul(buf, 0, 0); break;
 		case 14: winfo.city = buf; break;
 		case 15: winfo.state = buf; break;
 		case 16: winfo.phone = buf; break;
 		case 17: winfo.fax = buf; break;
 		case 18: winfo.street = buf; break;
 		case 19: winfo.zip = strtoul(buf, 0, 0); break;
-		case 20: winfo.country = buf; break;
+		case 20: winfo.country = strtoul(buf, 0, 0); break;
 		case 21: winfo.company = buf; break;
 		case 22: winfo.dept = buf; break;
 		case 23: winfo.position = buf; break;
-		case 24: break;
+		case 24: minfo.timezone = atoi(buf); break;
 		case 25: winfo.homepage = buf; break;
 		case 26: minfo.age = atoi(buf); break;
 		case 27: minfo.gender = (imgender) atoi(buf); break;
 		case 28: minfo.homepage = buf; break;
-		case 29: break;
-		case 30: break;
-		case 31: break;
+		case 29: minfo.lang1 = strtoul(buf, 0, 0); break;
+		case 30: minfo.lang2 = strtoul(buf, 0, 0); break;
+		case 31: minfo.lang3 = strtoul(buf, 0, 0); break;
 		case 32: minfo.birth_day = atoi(buf); break;
 		case 33: minfo.birth_month = atoi(buf); break;
 		case 34: minfo.birth_year = atoi(buf); break;
-		case 35: break;
-		case 36: break;
-		case 37: break;
-		case 38: break;
-		case 39: break;
-		case 40: break;
-		case 41: break;
+		case 35: if(strlen(buf)) interests.push_back(buf); break;
+		case 36: if(strlen(buf)) interests.push_back(buf); break;
+		case 37: if(strlen(buf)) interests.push_back(buf); break;
+		case 38: if(strlen(buf)) interests.push_back(buf); break;
+		case 39: if(strlen(buf)) background.push_back(buf); break;
+		case 40: if(strlen(buf)) background.push_back(buf); break;
+		case 41: if(strlen(buf)) background.push_back(buf); break;
 		case 42: break;
 		case 43: break;
 		case 44: lastip = buf; break;
@@ -306,7 +309,7 @@ void icqcontact::load() {
 
     if(dispnick.empty()) dispnick = nick;
 
-    if(conf.getusegroups())
+    if(conf.getgroupmode() != icqconf::nogroups)
     if(find(groups.begin(), groups.end(), groupid) == groups.end()) {
 	groupid = 1;
     }
@@ -434,6 +437,21 @@ void icqcontact::setworkinfo(const workinfo &ainfo) {
     fupdated++;
 }
 
+void icqcontact::setinterests(const vector<string> &ainterests) {
+    interests = ainterests;
+    fupdated++;
+}
+
+void icqcontact::setbackground(const vector<string> &abackground) {
+    background = abackground;
+    fupdated++;
+}
+
+void icqcontact::setabout(const string data) {
+    about = data;
+    fupdated++;
+}
+
 const icqcontact::basicinfo &icqcontact::getbasicinfo() const {
     return binfo;
 }
@@ -446,9 +464,12 @@ const icqcontact::workinfo &icqcontact::getworkinfo() const {
     return winfo;
 }
 
-void icqcontact::setabout(const string data) {
-    about = data;
-    fupdated++;
+const vector<string> &icqcontact::getinterests() const {
+    return interests;
+}
+
+const vector<string> &icqcontact::getbackground() const {
+    return background;
 }
 
 void icqcontact::setsound(imevent::imeventtype event, const string sf) {
@@ -461,7 +482,7 @@ void icqcontact::playsound(imevent::imeventtype event) const {
 
     if(sf.size()) {
 	if(sf[0] == '!') {
-	    time_t lastmelody = 0;
+	    static time_t lastmelody = 0;
 
 	    if(time(0)-lastmelody < 5) return;
 	    time(&lastmelody);
@@ -521,6 +542,7 @@ void icqcontact::playsound(imevent::imeventtype event) const {
 
 void icqcontact::setlastip(const string flastip) {
     lastip = flastip;
+    fupdated++;
 }
 
 const string icqcontact::getabout() const {
@@ -599,6 +621,17 @@ const imcontact icqcontact::getdesc() const {
 
 // ----------------------------------------------------------------------------
 
+const string icqcontact::moreinfo::strtimezone() const {
+    string r;
+
+    if(timezone <= 24 && timezone >= -24) {
+	r = ICQ2000::UserInfoHelpers::getTimezoneIDtoString(timezone) + ", " +
+	    ICQ2000::UserInfoHelpers::getTimezonetoLocaltime(timezone);
+    }
+
+    return r;
+}
+
 const string icqcontact::moreinfo::strbirthdate() const {
     string r;
 
