@@ -23,30 +23,38 @@ enum imgender {
 class icqcontact {
     public:
 	struct basicinfo {
-	    basicinfo(): zip(0) {};
+	    basicinfo(): zip(0), country(0), requiresauth(false) {};
 
-	    string fname, lname, email, city, state, phone, fax, street;
-	    string cellular, country;
+	    string fname, lname, email, city, state, phone, fax, street, cellular;
 	    unsigned int zip;
+	    unsigned short country;
+	    bool requiresauth;
 	};
 
 	struct moreinfo {
-	    moreinfo(): gender(genderUnspec), age(0) {};
+	    moreinfo():
+		gender(genderUnspec), age(0), birth_day(0),
+		birth_month(0), birth_year(0), lang1(0), lang2(0), lang3(0),
+		timezone(0) {};
 
 	    unsigned char age;
 	    imgender gender;
 	    string homepage;
 	    unsigned int birth_day, birth_month, birth_year;
+	    unsigned short lang1, lang2, lang3;
+	    signed char timezone;
 
 	    const string strbirthdate() const;
+	    const string strtimezone() const;
 	};
 
 	struct workinfo {
-	    workinfo(): zip(0) {};
+	    workinfo(): zip(0), country(0) {};
 
-	    string city, state, phone, fax, street, country, company;
+	    string city, state, phone, fax, street, company;
 	    string dept, position, homepage;
 	    unsigned int zip;
+	    unsigned short country;
 	};
 
     protected:
@@ -63,6 +71,7 @@ class icqcontact {
 	basicinfo binfo;
 	moreinfo minfo;
 	workinfo winfo;
+	vector<string> interests, background;
 
 	void scanhistory();
 	const string tosane(const string p) const;
@@ -81,12 +90,16 @@ class icqcontact {
 	void setbasicinfo(const basicinfo &ainfo);
 	void setmoreinfo(const moreinfo &ainfo);
 	void setworkinfo(const workinfo &ainfo);
+	void setinterests(const vector<string> &ainterests);
+	void setbackground(const vector<string> &abackground);
 	void setabout(const string data);
 	void setlastip(const string flastip);
 
 	const basicinfo &getbasicinfo() const;
 	const moreinfo &getmoreinfo() const;
 	const workinfo &getworkinfo() const;
+	const vector<string> &getinterests() const;
+	const vector<string> &getbackground() const;
 	const string getabout() const;
 	const string getlastip() const;
 
