@@ -1,7 +1,7 @@
 /*
 *
 * centericq user interface class, dialogs related part
-* $Id: icqdialogs.cc,v 1.38 2001/12/13 11:28:35 konst Exp $
+* $Id: icqdialogs.cc,v 1.45 2002/01/23 16:31:23 konst Exp $
 *
 * Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -85,22 +85,23 @@ bool icqface::finddialog(imsearchparams &s) {
 	switch(*ipname) {
 	    case icq:
 		i = tree.addnode(_(" UIN "));
-		tree.addleaff(i, 0, 10, _(" UIN : %s "), strint(s.uin));
-/*
+		tree.addleaff(i, 0, 10, " %s ", strint(s.uin));
+
 		i = tree.addnode(_(" Details "));
 		tree.addleaff(i, 0, 11, _(" Nickname : %s "), s.nick.c_str());
 		tree.addleaff(i, 0, 12, _(" E-Mail : %s "), s.email.c_str());
 		tree.addleaff(i, 0, 13, _(" First name : %s "), s.firstname.c_str());
 		tree.addleaff(i, 0, 14, _(" Last name : %s "), s.lastname.c_str());
+
 		tree.addleaff(i, 0, 15, _(" Min. age : %s "), strint(s.minage));
 		tree.addleaff(i, 0, 16, _(" Max. age : %s "), strint(s.maxage));
 		tree.addleaff(i, 0, 17, _(" Gender : %s "), strgender[s.gender]);
-		tree.addleaff(i, 0, 18, _(" Language : %s "), s.language ? icq_GetMetaLanguageName(s.language) : "");
+		tree.addleaff(i, 0, 18, _(" Language : %s "), strlanguage(s.language));
 
 		i = tree.addnode(_(" Location "));
 		tree.addleaff(i, 0, 19, _(" City : %s "), s.city.c_str());
 		tree.addleaff(i, 0, 20, _(" State : %s "), s.state.c_str());
-		tree.addleaff(i, 0, 21, _(" Country : %s "), s.country ? icq_GetCountryName(s.country) : "");
+		tree.addleaff(i, 0, 21, _(" Country : %s "), strcountry(s.country));
 
 		i = tree.addnode(_(" Work "));
 		tree.addleaff(i, 0, 22, _(" Company : %s "), s.company.c_str());
@@ -109,7 +110,6 @@ bool icqface::finddialog(imsearchparams &s) {
 
 		i = tree.addnode(_(" Online only "));
 		tree.addleaff(i, 0, 25, " %s ", stryesno[s.onlineonly]);
-*/
 		break;
 
 	    case yahoo:
@@ -141,10 +141,10 @@ bool icqface::finddialog(imsearchparams &s) {
 		    case 15: s.minage = atol(inputstr(_("Minimal age: "), strint(s.minage)).c_str()); break;
 		    case 16: s.maxage = atol(inputstr(_("Maximal age: "), strint(s.maxage)).c_str()); break;
 		    case 17: selectgender(s.gender); break;
-		    case 18: /*selectlanguage(s.language); */break;
+		    case 18: selectlanguage(s.language); break;
 		    case 19: s.city = inputstr(_("City: "), s.city); break;
 		    case 20: s.state = inputstr(_("State: "), s.state); break;
-		    case 21: /*selectcountry(s.country); */break;
+		    case 21: selectcountry(s.country); break;
 		    case 22: s.company = inputstr(_("Company: "), s.company); break;
 		    case 23: s.department = inputstr(_("Department: "), s.department); break;
 		    case 24: s.position = inputstr(_("Position: "), s.position); break;
@@ -193,7 +193,7 @@ void icqface::gendetails(treeview *tree, icqcontact *c = 0) {
     i = tree->addnode(_(" Home "));
     tree->addleaff(i, 0, 17, _(" City : %s "), bi.city.c_str());
     tree->addleaff(i, 0, 18, _(" State : %s "), bi.state.c_str());
-    tree->addleaff(i, 0, 19, _(" Country : %s "), bi.country.c_str());
+    tree->addleaff(i, 0, 19, _(" Country : %s "), strcountry(bi.country));
     tree->addleaff(i, 0, 20, _(" Street address : %s "), bi.street.c_str());
     tree->addleaff(i, 0, 21, _(" Zip code : %s "), strint(bi.zip));
     tree->addleaff(i, 0, 22, _(" Phone : %s "), bi.phone.c_str());
@@ -203,7 +203,7 @@ void icqface::gendetails(treeview *tree, icqcontact *c = 0) {
     i = tree->addnode(_(" Work "));
     tree->addleaff(i, 0, 25, _(" City : %s "), wi.city.c_str());
     tree->addleaff(i, 0, 26, _(" State : %s "), wi.state.c_str());
-    tree->addleaff(i, 0, 27, _(" Country : %s "), wi.country.c_str());
+    tree->addleaff(i, 0, 27, _(" Country : %s "), strcountry(wi.country));
     tree->addleaff(i, 0, 28, _(" Street address : %s "), wi.street.c_str());
     tree->addleaff(i, 0, 29, _(" Company : %s "), wi.company.c_str());
     tree->addleaff(i, 0, 30, _(" Department : %s "), wi.dept.c_str());
@@ -214,12 +214,17 @@ void icqface::gendetails(treeview *tree, icqcontact *c = 0) {
 
     i = tree->addnode(_(" More "));
     tree->addleaff(i, 0, 35, _(" Homepage : %s "), mi.homepage.c_str());
-//    tree->addleaff(i, 0, 0, _(" 1st language : %s "), flang1 ? icq_GetMetaLanguageName(flang1) : "");
-//    tree->addleaff(i, 0, 0, _(" 2nd language : %s "), flang2 ? icq_GetMetaLanguageName(flang2) : "");
-//    tree->addleaff(i, 0, 0, _(" 3rd language : %s "), flang3 ? icq_GetMetaLanguageName(flang3) : "");
+    tree->addleaff(i, 0, 36, _(" 1st language : %s "), strlanguage(mi.lang1));
+    tree->addleaff(i, 0, 37, _(" 2nd language : %s "), strlanguage(mi.lang2));
+    tree->addleaff(i, 0, 38, _(" 3rd language : %s "), strlanguage(mi.lang3));
+
+    if(c->getdesc().pname == icq)
+    if(c->getdesc() == contactroot)
+	tree->addleaff(i, 0, 40, _(" Require authorization : %s "),
+	    stryesno[bi.requiresauth]);
 
     i = tree->addnode(_(" About "));
-    tree->addleaff(i, 0, 36, " %s ", about.c_str());
+    tree->addleaff(i, 0, 39, " %s ", about.c_str());
 
     tree->menu.setpos(saveitem, savefirst);
 }
@@ -276,12 +281,10 @@ bool icqface::updatedetails(icqcontact *c = 0) {
 	about = c->getabout();
 
 	if(!b) {
-/*
-	    if(!c->getdesc().uin && (c->updated() < 5)) {
-		status(_("Wait a moment. Your ICQ details haven't been fetched yet"));
+	    if((c->getdesc() == contactroot) && !c->updated()) {
+		status(_("Wait a moment. Your details haven't been fetched yet"));
 		continue;
 	    } else
-*/
 	    switch(citem) {
 		case 10:
 		    c->setnick(inputstr(_("Nickname: "), c->getnick()));
@@ -324,7 +327,7 @@ bool icqface::updatedetails(icqcontact *c = 0) {
 
 		case 17: bi.city = inputstr(_("City: "), bi.city); break;
 		case 18: bi.state = inputstr(_("State: "), bi.state); break;
-		case 19: /*selectcountry(bi.country); */break;
+		case 19: selectcountry(bi.country); break;
 		case 20: bi.street = inputstr(_("Street address: "), bi.street); break;
 		case 21: bi.zip = strtoul(inputstr(_("Zip code: "), strint(bi.zip)).c_str(), 0, 0); break;
 		case 22: bi.phone = inputstr(_("Phone: "), bi.phone); break;
@@ -333,7 +336,7 @@ bool icqface::updatedetails(icqcontact *c = 0) {
 
 		case 25: wi.city = inputstr(_("City: "), wi.city); break;
 		case 26: wi.state = inputstr(_("State: "), wi.state); break;
-		case 27: /*selectcountry(wi.country); */break;
+		case 27: selectcountry(wi.country); break;
 		case 28: wi.street = inputstr(_("Street address: "), wi.street); break;
 		case 29: wi.company = inputstr(_("Company: "), wi.company); break;
 		case 30: wi.dept = inputstr(_("Department: "), wi.dept); break;
@@ -344,7 +347,12 @@ bool icqface::updatedetails(icqcontact *c = 0) {
 
 		case 35: mi.homepage = inputstr(_("Homepage: "), mi.homepage); break;
 
-		case 36: editabout(about); break;
+		case 36: selectlanguage(mi.lang1); break;
+		case 37: selectlanguage(mi.lang2); break;
+		case 38: selectlanguage(mi.lang3); break;
+
+		case 39: editabout(about); break;
+		case 40: bi.requiresauth = !bi.requiresauth; break;
 	    }
 
 	    c->setbasicinfo(bi);
@@ -352,7 +360,7 @@ bool icqface::updatedetails(icqcontact *c = 0) {
 	    c->setworkinfo(wi);
 	    c->setabout(about);
 	} else {
-	    ret = c->getdesc().uin || (c->updated() >= 5);
+	    ret = (c->getdesc() != contactroot) || c->updated();
 	    finished = true;
 	}
     }
@@ -366,21 +374,18 @@ bool icqface::updatedetails(icqcontact *c = 0) {
     return ret;
 }
 
-/*
 void icqface::selectcountry(unsigned short &f) {
     int i;
 
     verticalmenu m(conf.getcolor(cp_dialog_menu), conf.getcolor(cp_dialog_selected));
     m.setwindow(textwindow(4, LINES-16, 30, LINES-3, conf.getcolor(cp_dialog_menu)));
 
-    m.additem(0, 0, (string) " " + _("Not entered"));
+    for(i = 0; i < ICQ2000::Country_table_size; i++) {
+	m.additem(0, (int) ICQ2000::Country_table[i].code,
+	    (string) " " + ICQ2000::Country_table[i].name);
 
-    for(i = 0;; i++) {
-	if(icq_Countries[i].code == 0xffff) break; else {
-	    m.additem(0, (int) icq_Countries[i].code, (string) " " + icq_Countries[i].name);
-	    if(icq_Countries[i].code == f) {
-		m.setpos(i+1);
-	    }
+	if(ICQ2000::Country_table[i].code == f) {
+	    m.setpos(i);
 	}
     }
 
@@ -390,19 +395,21 @@ void icqface::selectcountry(unsigned short &f) {
     if(i) f = (unsigned short) ((int) m.getref(i-1));
 }
 
-void icqface::selectlanguage(unsigned char &f) {
+void icqface::selectlanguage(unsigned short &f) {
     int i;
     verticalmenu m(conf.getcolor(cp_dialog_menu), conf.getcolor(cp_dialog_selected));
     m.setwindow(textwindow(4, LINES-13, 20, LINES-4, conf.getcolor(cp_dialog_menu)));
 
-    for(i = 0; i <= 67; i++) m.additemf(" %s", icq_GetMetaLanguageName(i));
+    for(i = 0; i < ICQ2000::Language_table_size; i++) {
+	m.additemf(" %s", ICQ2000::Language_table[i]);
+    }
+
     m.setpos(f);
     i = m.open();
     m.close();
     
     if(i) f = i-1;
 }
-*/
 
 void icqface::selectgender(imgender &f) {
     verticalmenu m(conf.getcolor(cp_dialog_menu), conf.getcolor(cp_dialog_selected));
@@ -513,7 +520,7 @@ bool icqface::sendfiles(const imcontact cinfo, string &msg, linkedlist &flist) {
     return flist.count;
 }
 
-bool icqface::updateconf(regsound &s, regcolor &c) {
+bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
     bool finished, success;
     int nopt, n, i, b, nproxy, nconf, ncomm, aaway, ana, noth, nfeat, ncl;
     string tmp, phidden, socksuser, sockspass;
@@ -526,7 +533,9 @@ bool icqface::updateconf(regsound &s, regcolor &c) {
     bool hideoffl = conf.gethideoffline();
     bool antispam = conf.getantispam();
     bool mailcheck = conf.getmailcheck();
-    bool usegroups = conf.getusegroups();
+    bool makelog = conf.getmakelog();
+
+    icqconf::groupmode gmode = conf.getgroupmode();
 
     dialogbox db;
 
@@ -560,7 +569,7 @@ bool icqface::updateconf(regsound &s, regcolor &c) {
 	t.addleaff(i, 0, 2, _(" Change color scheme to : %s "), strregcolor(c));
 
 	i = t.addnode(_(" Contact list "));
-	t.addleaff(i, 0, 17, _(" Arrange contacts into groups : %s "), stryesno[usegroups]);
+	t.addleaff(i, 0, 17, _(" Arrange contacts into groups : %s "), strgroupmode(gmode));
 	t.addleaff(i, 0,  6, _(" Hide offline users : %s "), stryesno[hideoffl]);
 	t.addleaff(i, 0,  3, _(" Russian translation win1251-koi8 needed : %s "), stryesno[rus]);
 	t.addleaff(i, 0, 14, _(" Anti-spam: kill msgs from users not on the list : %s "), stryesno[antispam]);
@@ -575,6 +584,7 @@ bool icqface::updateconf(regsound &s, regcolor &c) {
 	i = t.addnode(_(" Miscellaneous "));
 	t.addleaff(i, 0, 4, _(" Automatically set Away period (min) : %d "), aaway);
 	t.addleaff(i, 0, 5, _(" Automatically set N/A period (min) : %d "), ana);
+	t.addleaff(i, 0, 18, _(" Detailed IM events log in ~/.centericq/log : %s "), stryesno[makelog]);
 
 	if(socks) {
 	    conf.getsocksuser(socksuser, sockspass);
@@ -593,13 +603,15 @@ bool icqface::updateconf(regsound &s, regcolor &c) {
 	    case 0:
 		switch(i) {
 		    case 1:
-			s = s == rsdontchange ? rscard :
-			    s == rscard ? rsspeaker :
-			    s == rsspeaker ? rsdisable : rsdontchange;
+			s = s == icqconf::rsdontchange ? icqconf::rscard :
+			    s == icqconf::rscard ? icqconf::rsspeaker :
+			    s == icqconf::rsspeaker ? icqconf::rsdisable :
+				icqconf::rsdontchange;
 			break;
 		    case 2:
-			c = c == rcdontchange ? rcdark :
-			    c == rcdark ? rcblue : rcdontchange;
+			c = c == icqconf::rcdontchange ? icqconf::rcdark :
+			    c == icqconf::rcdark ? icqconf::rcblue :
+				icqconf::rcdontchange;
 			break;
 		    case 3: rus = !rus; break;
 		    case 4:
@@ -628,7 +640,13 @@ bool icqface::updateconf(regsound &s, regcolor &c) {
 		    case 13: savepwd = !savepwd; break;
 		    case 14: antispam = !antispam; break;
 		    case 15: mailcheck = !mailcheck; break;
-		    case 17: usegroups = !usegroups; break;
+		    case 17:
+			gmode =
+			    gmode == icqconf::group1 ? icqconf::group2 :
+			    gmode == icqconf::group2 ? icqconf::nogroups :
+				icqconf::group1;
+			break;
+		    case 18: makelog = !makelog; break;
 		}
 		break;
 	    case 1:
@@ -640,9 +658,10 @@ bool icqface::updateconf(regsound &s, regcolor &c) {
 		conf.setantispam(antispam);
 		conf.setmailcheck(mailcheck);
 		conf.setrussian(rus);
+		conf.setmakelog(makelog);
 
-		if(conf.getusegroups() != usegroups) {
-		    conf.setusegroups(usegroups);
+		if(conf.getgroupmode() != gmode) {
+		    conf.setgroupmode(gmode);
 		    clist.rearrange();
 		}
 
@@ -671,10 +690,10 @@ void icqface::detailsidle(dialogbox &db) {
 
     if(!cicq.idle(HIDL_SOCKEXIT))
     if(c = clist.get(contactroot))
-    if(c->updated() >= 5) {
+    if(c->updated()) {
 	face.gendetails(db.gettree());
 	db.gettree()->redraw();
-	face.status(_("Your ICQ details have been fetched"));
+	face.status(_("Your details have been fetched"));
     }
 }
 
