@@ -1,7 +1,7 @@
 /*
 *
 * centericq user interface class
-* $Id: icqface.cc,v 1.60 2001/12/14 16:30:06 konst Exp $
+* $Id: icqface.cc,v 1.75 2002/01/31 18:03:26 konst Exp $
 *
 * Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -30,17 +30,18 @@
 #include "icqmlist.h"
 #include "icqgroups.h"
 #include "abstracthook.h"
+#include "imlogger.h"
 
-const char *strregsound(regsound s) {
-    return s == rscard ? _("sound card") :
-	s == rsspeaker ? _("speaker") :
-	s == rsdisable ? _("disable") :
+const char *strregsound(icqconf::regsound s) {
+    return s == icqconf::rscard ? _("sound card") :
+	s == icqconf::rsspeaker ? _("speaker") :
+	s == icqconf::rsdisable ? _("disable") :
 	_("don't change");
 }
 
-const char *strregcolor(regcolor c) {
-    return c == rcdark ? _("dark") :
-	c == rcblue ? _("blue") :
+const char *strregcolor(icqconf::regcolor c) {
+    return c == icqconf::rcdark ? _("dark") :
+	c == icqconf::rcblue ? _("blue") :
 	_("don't change");
 }
 
@@ -49,6 +50,30 @@ const char *strint(unsigned int i) {
     return i ? (s = i2str(i)).c_str() : "";
 }
 
+const char *strcountry(unsigned int code) {
+    int i;
+    for(i = 0; i < ICQ2000::Country_table_size; i++) {
+	if(ICQ2000::Country_table[i].code == code) {
+	    return ICQ2000::Country_table[i].name;
+	}
+    }
+    return "";
+}
+
+const char *strlanguage(unsigned int code) {
+    if(code < ICQ2000::Language_table_size) {
+	return ICQ2000::Language_table[code];
+    } else {
+	return "";
+    }
+}
+
+const char *strgroupmode(icqconf::groupmode gmode) {
+    return gmode == icqconf::group1 ? _("mode 1") :
+	gmode == icqconf::group2 ? _("mode 2") :
+	    _("no");
+}
+
 icqface::icqface() {
     kinterface();
     raw();
@@ -73,9 +98,9 @@ void icqface::init() {
     if(!flog.is_open()) {
 	time_t logtime = time(0);
 
-	flog.open((conf.getdirname() + "log").c_str(), ios::app);
+	flog.open((conf.getdirname() + "debug").c_str(), ios::app);
 	if(flog.is_open())
-	    flog << endl << "-- centericq log started on " << ctime(&logtime);
+	    flog << endl << "-- centericq debug log started on " << ctime(&logtime);
     }
 #endif
 
@@ -170,19 +195,16 @@ int icqface::contextmenu(icqcontact *c) {
     capab = gethook(cont.pname).getcapabilities();
 
     if(cont != contactroot) {
-	if(cont.pname != infocard) {
+	if(cont.pname != infocard)
 	    m.additem(0, ACT_MSG, _(" Send a message     enter"));
-	}
 
-	if(capab & hoptCanSendURL) {
+	if(capab & hoptCanSendURL)
 	    m.additem(0, ACT_URL, _(" Send an URL            u"));
-	}
 
-	if(capab & hoptCanSendSMS) {
+	if(capab & hoptCanSendSMS)
 	    m.additem(0, ACT_SMS, _(" Send an SMS"));
-	}
 
-	m.addline();
+	if(!m.empty()) m.addline();
 
 	m.additem(0, ACT_INFO, _(" User's details         ?"));
 	m.additem(0, ACT_EDITUSER, _(" Edit details"));
@@ -193,9 +215,9 @@ int icqface::contextmenu(icqcontact *c) {
     if(cont != contactroot) {
 	m.addline();
 
-	if(c->inlist()) {
-	    m.additem(0, ACT_IGNORE, _(" Ignore user"));
-	} else {
+	m.additem(0, ACT_IGNORE, _(" Ignore user"));
+
+	if(!c->inlist()) {
 	    m.additem(0, ACT_ADD, _(" Add to list            a"));
 	}
     }
@@ -203,7 +225,7 @@ int icqface::contextmenu(icqcontact *c) {
     if(c->getdesc() != contactroot) {
 	m.additem(0, ACT_REMOVE, _(" Remove user          del"));
 	m.additem(0, ACT_RENAME, _(" Rename contact         r"));
-	if(conf.getusegroups())
+	if(conf.getgroupmode() != icqconf::nogroups)
 	    m.additem(0, ACT_GROUPMOVE, _(" Move to group.."));
     }
 
@@ -239,7 +261,7 @@ int icqface::generalmenu() {
 	_(" Show offline users                 F5") :
 	_(" Hide offline users                 F5"));
 
-    if(conf.getusegroups()) {
+    if(conf.getgroupmode() != icqconf::nogroups) {
 	m.additem(0,  ACT_ORG_GROUPS, (string) " " + _("Organize contact groups"));
     }
 
@@ -310,8 +332,15 @@ icqcontact *icqface::mainloop(int &action) {
     return c;
 }
 
+#define ADDGROUP(nn) { \
+    if(groupchange && !strchr("!", sc)) \
+	ngroup = mcontacts->addnode(nn, conf.getcolor(cp_main_highlight), \
+	    0, " " + find(groups.begin(), groups.end(), \
+	    c->getgroupid())->getname() + " "); \
+}
+
 void icqface::fillcontactlist() {
-    int i, id, nnode, ngroup, prevgid;
+    int i, id, nnode, ngroup, prevgid, n, nonline;
     string dnick;
     icqcontact *c;
     void *savec;
@@ -323,11 +352,7 @@ void icqface::fillcontactlist() {
     savec = mcontacts->getref(mcontacts->getid(mcontacts->menu.getpos()));
     mcontacts->clear();
     clist.order();
-/*
-    if(c = clist.get(contactroot))
-    if(c->getmsgcount())
-	mcontacts->addleaf(0, conf.getcolor(cp_main_highlight), c, "#ICQ ");
-*/
+
     for(i = 0; i < clist.count; i++) {
 	c = (icqcontact *) clist.at(i);
 
@@ -343,37 +368,61 @@ void icqface::fillcontactlist() {
 	sc = SORTCHAR(c);
 
 	groupchange =
-	    conf.getusegroups() &&
+	    (conf.getgroupmode() != icqconf::nogroups) &&
 	    (c->getgroupid() != prevgid) &&
 	    (sc != '#');
 
-	if(groupchange && !strchr("!", sc)) {
-	    ngroup = mcontacts->addnode(0, conf.getcolor(cp_main_highlight),
-		0, " " + find(groups.begin(), groups.end(),
-		c->getgroupid())->getname() + " ");
-	}
+	if(conf.getgroupmode() == icqconf::group1)
+	    ADDGROUP(0);
 
 	if(groupchange || (sc != '#')) {
 	    if(strchr("candifo", sc)) sc = 'O';
 
-	    if((sc != prevsc) || groupchange)
-	    switch(sc) {
-		case 'O':
-		    nnode = conf.gethideoffline() && conf.getusegroups() ?
-			ngroup : mcontacts->addnode(ngroup,
-			    conf.getcolor(cp_main_highlight), 0, " Online ");
+	    if((sc != prevsc) || groupchange) {
+		switch(conf.getgroupmode()) {
+		    case icqconf::group1:
+			n = ngroup;
+			break;
+		    case icqconf::group2:
+			if(prevsc == sc) {
+			    n = -1;
+			} else {
+			    n = 0;
+			}
+			break;
+		    default:
+			n = 0;
+			break;
+		}
 
-		    online_added = true;
-		    break;
-		case '_':
-		    nnode = mcontacts->addnode(ngroup,
-			conf.getcolor(cp_main_highlight), 0, " Offline ");
-		    break;
-		case '!':
-		    ngroup = 0;
-		    nnode = mcontacts->addnode(ngroup,
-			conf.getcolor(cp_main_highlight), 0, " Not in list ");
-		    break;
+		if(n != -1) {
+		    switch(sc) {
+			case 'O':
+			    nnode = conf.gethideoffline() && (conf.getgroupmode() != icqconf::nogroups) ?
+				n : mcontacts->addnode(n,
+				    conf.getcolor(cp_main_highlight), 0, " Online ");
+
+			    online_added = true;
+			    break;
+			case '_':
+			    nnode = mcontacts->addnode(n,
+				conf.getcolor(cp_main_highlight), 0, " Offline ");
+			    break;
+			case '!':
+			    ngroup = 0;
+			    nnode = mcontacts->addnode(ngroup,
+				conf.getcolor(cp_main_highlight), 0, " Not in list ");
+			    break;
+		    }
+
+		    nonline = nnode;
+		}
+
+		if(conf.getgroupmode() == icqconf::group2)
+		if(sc != '!') {
+		    ADDGROUP(nonline);
+		    nnode = ngroup;
+		}
 	    }
 
 	    if(groupchange) prevgid = c->getgroupid();
@@ -393,11 +442,7 @@ void icqface::fillcontactlist() {
 		c, "%s[%c] %s ", c->getmsgcount() ? "#" : " ", c->getshortstatus(), dnick.c_str());
 	}
     }
-/*
-    if(c = clist.get(contactroot))
-    if(!c->getmsgcount())
-	mcontacts->addleaf(0, conf.getcolor(cp_clist_root), c, " ICQ ");
-*/
+
     if(!mainscreenblock) mcontacts->redraw();
 
     if(!savec || (!onlinefolder && online_added && conf.gethideoffline())) {
@@ -418,7 +463,7 @@ void icqface::fillcontactlist() {
     }
 }
 
-bool icqface::findresults() {
+bool icqface::findresults(const imsearchparams &sp) {
     bool finished = false, ret = false;
     unsigned int ffuin;
     icqcontact *c;
@@ -435,10 +480,9 @@ bool icqface::findresults() {
     db.setbar(new horizontalbar(conf.getcolor(cp_main_highlight),
 	conf.getcolor(cp_main_selected), _("Details"), _("Add"),
 	_("New search"), 0));
-/*
-    ihook.clearfindresults();
-    ihook.setfinddest(db.getmenu());
-*/
+
+    gethook(sp.pname).lookup(sp, *db.getmenu());
+
     db.addautokeys();
     db.idle = &dialogidle;
     db.redraw();
@@ -450,23 +494,21 @@ bool icqface::findresults() {
 
     while(!finished) {
 	finished = !db.open(r, b);
-//        ihook.setfinddest(0);
-	
+	gethook(sp.pname).stoplookup();
+
 	if(!finished)
 	switch(b) {
 	    case 0:
-/*
-		if(ffuin = ihook.getfinduin(r)) {
-		    cicq.userinfo(imcontact(ffuin, icq));
+		if(r) {
+		    r = (int) db.getmenu()->getref(r-1);
+		    if(r) cicq.userinfo(imcontact(r, icq));
 		}
-*/
 		break;
 	    case 1:
-/*
-		if(ffuin = ihook.getfinduin(r)) {
-		    cicq.addcontact(imcontact(ffuin, icq));
+		if(r) {
+		    r = (int) db.getmenu()->getref(r-1);
+		    if(r) cicq.addcontact(imcontact(r, icq));
 		}
-*/
 		break;
 	    case 2:
 		ret = finished = true;
@@ -509,7 +551,38 @@ void icqface::infoclear(dialogbox &db, icqcontact *c, const imcontact realdesc)
 	extractedurls.push_back(wi.homepage);
 }
 
+void commacat(string &text, string sub, bool nocomma = false) {
+    if(!sub.empty()) {
+	if(!nocomma)
+	if(text[text.size()-1] != ',') text += ",";
+
+	text += sub;
+    }
+}
+
+void commaform(string &text) {
+    int pos = 0, ipos;
+
+    while((pos = text.find(",", pos)) != -1) {
+	if(text.substr(pos+1, 1) != " ") {
+	    text.insert(pos+1, " ");
+	}
+
+	ipos = pos-1;
+	while(ipos > 0) {
+	    if(text.substr(ipos, 1) == " ") {
+		text.erase(ipos--, 1);
+	    } else {
+		break;
+	    }
+	}
+
+	pos++;
+    }
+}
+
 void icqface::infogeneral(dialogbox &db, icqcontact *c) {
+    string langs;
     icqcontact::basicinfo bi = c->getbasicinfo();
     icqcontact::moreinfo mi = c->getmoreinfo();
 
@@ -535,6 +608,12 @@ void icqface::infogeneral(dialogbox &db, icqcontact *c) {
     mainw.write(WORKAREA_X1+14, WORKAREA_Y1+9, conf.getcolor(cp_main_text), mi.strbirthdate());
     mainw.write(WORKAREA_X1+14, WORKAREA_Y1+10, conf.getcolor(cp_main_text), mi.age ? i2str(mi.age) : "");
 
+    if(mi.lang1) commacat(langs, strlanguage(mi.lang1), langs.empty());
+    if(mi.lang2) commacat(langs, strlanguage(mi.lang2), langs.empty());
+    if(mi.lang3) commacat(langs, strlanguage(mi.lang3), langs.empty());
+    commaform(langs);
+
+    mainw.write(WORKAREA_X1+14, WORKAREA_Y1+12, conf.getcolor(cp_main_text), langs);
     mainw.write(WORKAREA_X1+14, WORKAREA_Y1+13, conf.getcolor(cp_main_text), c->getlastip());
 
     if(c->getstatus() == offline) {
@@ -570,9 +649,9 @@ void icqface::infohome(dialogbox &db, icqcontact *c) {
 	bi.city += bi.state;
     }
 
-    if(!bi.country.empty()) {
+    if(bi.country) {
 	if(bi.city.size()) bi.city += ", ";
-	bi.city += bi.country;
+	bi.city += strcountry(bi.country);
     }
 
     x += 10;
@@ -582,6 +661,7 @@ void icqface::infohome(dialogbox &db, icqcontact *c) {
     mainw.write(x, WORKAREA_Y1+5, conf.getcolor(cp_main_text), bi.phone);
     mainw.write(x, WORKAREA_Y1+6, conf.getcolor(cp_main_text), bi.fax);
     mainw.write(x, WORKAREA_Y1+7, conf.getcolor(cp_main_text), bi.cellular);
+    mainw.write(x, WORKAREA_Y1+8, conf.getcolor(cp_main_text), mi.strtimezone());
 
     for(i = 0; !mi.homepage.empty(); i++) {
 	mainw.write(x, WORKAREA_Y1+10+i, conf.getcolor(cp_main_text),
@@ -603,8 +683,7 @@ void icqface::infowork(dialogbox &db, icqcontact *c) {
 
     mainw.write(WORKAREA_X1+2, WORKAREA_Y1+6, conf.getcolor(cp_main_highlight), _("Company"));
     mainw.write(WORKAREA_X1+2, WORKAREA_Y1+7, conf.getcolor(cp_main_highlight), _("Department"));
-    mainw.write(WORKAREA_X1+2, WORKAREA_Y1+8, conf.getcolor(cp_main_highlight), _("Occupation"));
-    mainw.write(WORKAREA_X1+2, WORKAREA_Y1+9, conf.getcolor(cp_main_highlight), _("Title"));
+    mainw.write(WORKAREA_X1+2, WORKAREA_Y1+8, conf.getcolor(cp_main_highlight), _("Title"));
 
     mainw.write(WORKAREA_X1+2, WORKAREA_Y1+11, conf.getcolor(cp_main_highlight), _("Phone"));
     mainw.write(WORKAREA_X1+2, WORKAREA_Y1+12, conf.getcolor(cp_main_highlight), _("Fax"));
@@ -615,9 +694,9 @@ void icqface::infowork(dialogbox &db, icqcontact *c) {
 	wi.city += wi.state;
     }
 
-    if(!wi.country.empty()) {
+    if(wi.country) {
 	if(wi.city.size()) wi.city += ", ";
-	wi.city += wi.country;
+	wi.city += strcountry(wi.country);
     }
 
     mainw.write(WORKAREA_X1+14, WORKAREA_Y1+2, conf.getcolor(cp_main_text), wi.street);
@@ -625,7 +704,7 @@ void icqface::infowork(dialogbox &db, icqcontact *c) {
     mainw.write(WORKAREA_X1+14, WORKAREA_Y1+4, conf.getcolor(cp_main_text), wi.zip ? i2str(wi.zip) : "");
     mainw.write(WORKAREA_X1+14, WORKAREA_Y1+6, conf.getcolor(cp_main_text), wi.company);
     mainw.write(WORKAREA_X1+14, WORKAREA_Y1+7, conf.getcolor(cp_main_text), wi.dept);
-    mainw.write(WORKAREA_X1+14, WORKAREA_Y1+9, conf.getcolor(cp_main_text), wi.position);
+    mainw.write(WORKAREA_X1+14, WORKAREA_Y1+8, conf.getcolor(cp_main_text), wi.position);
     mainw.write(WORKAREA_X1+14, WORKAREA_Y1+11, conf.getcolor(cp_main_text), wi.phone);
     mainw.write(WORKAREA_X1+14, WORKAREA_Y1+12, conf.getcolor(cp_main_text), wi.fax);
 
@@ -640,17 +719,33 @@ void icqface::infoabout(dialogbox &db, icqcontact *c) {
     db.getbrowser()->setbuf(c->getabout());
 }
 
-void commacat(string &text, string sub, bool nocomma = false) {
-    if(!sub.empty()) {
-	if(!nocomma)
-	if(text[text.size()-1] != ',') text += ",";
-
-	text += sub;
-    }
-}
-
 void icqface::infointerests(dialogbox &db, icqcontact *c) {
     string text;
+    vector<string> data;
+    vector<string>::iterator i;
+
+    data = c->getinterests();
+
+    if(!data.empty()) {
+	text += (string) "* " + _("Interests") + "\n";
+
+	for(i = data.begin(); i != data.end(); i++) {
+	    text += " + " + *i + "\n";
+	}
+
+	text += "\n";
+    }
+
+    data = c->getbackground();
+
+    if(!data.empty()) {
+	text += (string) "* " + _("Background") + "\n";
+
+	for(i = data.begin(); i != data.end(); i++)
+	    text += " + " + *i + "\n";
+    }
+
+    commaform(text);
     db.getbrowser()->setbuf(text);
 }
 
@@ -715,6 +810,7 @@ void icqface::userinfo(const imcontact cinfo, const imcontact realinfo) {
 		    switch(cinfo.pname) {
 			case infocard:
 			    updatedetails(c);
+			    showinfo = true;
 			    break;
 
 			default:
@@ -723,7 +819,6 @@ void icqface::userinfo(const imcontact cinfo, const imcontact realinfo) {
 		    }
 
 		    b = lastb;
-		    showinfo = true;
 		    continue;
 	    }
 
@@ -1246,7 +1341,9 @@ void icqface::quickfind(verticalmenu *multi = 0) {
 		    bool fpass = true;
 
 		    for(; !fin; i++) {
-			if(i >= cm->getcount()) {
+			c = 0;
+
+			if(i > cm->getcount()) {
 			    if(fpass) {
 				i = 0;
 				fpass = false;
@@ -1257,7 +1354,8 @@ void icqface::quickfind(verticalmenu *multi = 0) {
 			}
 
 			if(multi) {
-			    c = clist.get(*((imcontact *) cm->getref(i)));
+			    imcontact *cnt = (imcontact *) cm->getref(i);
+			    if(cnt) c = clist.get(*cnt);
 			} else {
 			    c = (icqcontact *) mcontacts->getref(i);
 			}
@@ -1474,6 +1572,12 @@ icqface::eventviewresult icqface::eventview(const imevent *ev) {
 	}
 	actions.push_back(ok);
 
+    } else if(ev->gettype() == imevent::email) {
+	const imemail *m = static_cast<const imemail *>(ev);
+	text = m->gettext();
+
+	actions.push_back(forward);
+	actions.push_back(ok);
     }
 
     saveworkarea();
@@ -1562,6 +1666,12 @@ void icqface::histmake(const vector<imevent *> &hist) {
 	} else if(ev.gettype() == imevent::sms) {
 	    const imsms *m = static_cast<const imsms *>(&ev);
 	    text += m->gettext();
+	} else if(ev.gettype() == imevent::authorization) {
+	    const imauthorization *m = static_cast<const imauthorization *>(&ev);
+	    text += m->gettext();
+	} else if(ev.gettype() == imevent::email) {
+	    const imemail *m = static_cast<const imemail *>(&ev);
+	    text += m->gettext();
 	}
 
 	if(ev.getdirection() == imevent::incoming) {
@@ -1600,7 +1710,8 @@ bool icqface::histexec(imevent *&im) {
 	im = static_cast<imevent *> (mhist.getref(0));
 
 	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1, conf.getcolor(cp_main_highlight),
-	    _("History items for %s"), im->getcontact().totext().c_str());
+	    _("History for %s, %d events total"),
+	    im->getcontact().totext().c_str(), mhist.getcount());
 
 	status(_("S search, L again, ESC cancel"));
 
