@@ -14,6 +14,8 @@
 #include "icqmlist.h"
 #include "imcontroller.h"
 
+#include <libicq2000/userinfoconstants.h>
+
 #define DIALOG_WIDTH    60
 #define DIALOG_HEIGHT   15
 
@@ -123,10 +125,10 @@ class icqface {
 
 	void gendetails(treeview *tree, icqcontact *c = 0);
 	void selectgender(imgender &f);
-/*
+
 	void selectcountry(unsigned short &f);
-	void selectlanguage(unsigned char &f);
-*/
+	void selectlanguage(unsigned short &f);
+
 	void editabout(string &fabout);
 
 	void saveworkarea();
@@ -175,10 +177,10 @@ class icqface {
 	bool multicontacts(const string head = "");
 	void userinfo(const imcontact cinfo, const imcontact realinfo);
 
-	bool updateconf(regsound &s, regcolor &c);
+	bool updateconf(icqconf::regsound &s, icqconf::regcolor &c);
 
 	bool finddialog(imsearchparams &s);
-	bool findresults();
+	bool findresults(const imsearchparams &sp);
 
 	bool updatedetails(icqcontact *c = 0);
 	bool sendfiles(const imcontact cinfo, string &msg, linkedlist &flist);
@@ -209,9 +211,12 @@ extern icqface face;
 
 string getbdate(unsigned char fbday, unsigned char fbmonth, unsigned char fbyear);
 
-const char *strregsound(regsound s);
-const char *strregcolor(regcolor c);
+const char *strregsound(icqconf::regsound s);
+const char *strregcolor(icqconf::regcolor c);
 const char *strint(unsigned int i);
+const char *strcountry(unsigned int code);
+const char *strlanguage(unsigned int code);
+const char *strgroupmode(icqconf::groupmode gmode);
 
 static const char *stryesno[true+1] = {
     _("no"), _("yes")
@@ -223,10 +228,6 @@ static const char *strgender[imgender_size] = {
     _("Female")
 };
 
-static const char *eventnames[imevent::imeventtype_size] = {
-    _("message"), _("URL"), _("SMS"), _("authorization")
-};
-
 static const char *eventviewresultnames[icqface::eventviewresult_size] = {
     "", _("Fwd"), _("Reply"), _("Ok"),
     _("Open"), _("Accept"), _("Reject")
